<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php $settings = Engine_Api::_()->getApi('settings', 'core'); ?>
<div class="inspira_footer">
   <div class="row">
      <div class="col-md-4">
         <div class="inspira_footer_left">
            <?php if($settings->getSetting('inspira.footer.logo')) { ?>
              <div class="footer_logo">
                <img src="<?php echo $settings->getSetting('inspira.footer.logo'); ?>" alt="">
              </div>
            <?php } ?>
            <?php if($settings->getSetting('inspira.leftcolhdingdes')) { ?>
              <p><?php echo $this->translate($settings->getSetting('inspira.leftcolhdingdes', 'Inspire creativity, community, and awareness! SocialEngine PHP - the best choice for community social networking software.')); ?></p>
            <?php } ?>
            <?php if($settings->getSetting('inspira.leftcolhdinglocation') || $settings->getSetting('inspira.leftcolhdingemail') || $settings->getSetting('inspira.leftcolhdingphone')) { ?>
              <ul>
                <?php if($settings->getSetting('inspira.leftcolhdinglocation')) { ?>
                  <li><i class="fa-solid fa-location-dot"></i> <?php echo $settings->getSetting('inspira.leftcolhdinglocation', 'Los Angeles, USA'); ?></li>
                <?php } ?>
                <?php if($settings->getSetting('inspira.leftcolhdingemail')) { ?>
                  <li><i class="fa-solid fa-envelope"></i> <?php echo $settings->getSetting('inspira.leftcolhdingemail', 'info@abc.com'); ?></li>
                <?php } ?>
                <?php if($settings->getSetting('inspira.leftcolhdingphone')) { ?>
                  <li><i class="fa-solid fa-headphones"></i> <?php echo $settings->getSetting('inspira.leftcolhdingphone', '+91-1234567890'); ?></li>
                <?php } ?>
              </ul>
            <?php } ?>
         </div>
      </div>
      <?php if($settings->getSetting('inspira.quicklinksenable', '1')) { ?>
        <div class="col-md-2">
          <div class="footer_links_menu">
              <h3 class="custom_footer_heading"><?php echo $this->translate("Explore"); ?></h3>
              <ul class="footer_link_bottom">
                <?php foreach( $this->quickLinksMenu as $link ): 
                $attribs = array_diff_key(array_filter($link->toArray()), array_flip(array(
                  'reset_params', 'route', 'module', 'controller', 'action', 'type',
                  'visible', 'label', 'href'
                )));
                ?>
                  <li>
                      <?php if($link->get('icon')) { ?>
                        <i class="fa <?php echo $link->get('icon') ? $link->get('icon') : 'fa-star' ?>"></i>
                      <?php } ?>
                      <?php echo $this->htmlLink($link->getHref(), $this->translate($link->getLabel()), $attribs) ?>
                    </a>
                  </li>
                <?php endforeach; ?>
              </ul>
          </div>
        </div>
      <?php } ?>
      <?php if($settings->getSetting('inspira.helpenable', '1')) { ?>
      <div class="col-md-2">
         <div class="footer_links_menu">
            <h3 class="custom_footer_heading"><?php echo $this->translate("Help"); ?></h3>
            <div class="footer_link_bottom">
               <?php foreach( $this->navigation as $item ):
                  $attribs = array_diff_key(array_filter($item->toArray()), array_flip(array(
                  'reset_params', 'route', 'module', 'controller', 'action', 'type',
                  'visible', 'label', 'href'
                  )));
                  ?>
               <?php echo $this->htmlLink($item->getHref(), $this->translate($item->getLabel()), $attribs) ?>
               <?php endforeach; ?>
            </div>
         </div>
      </div>
      <?php } ?>
      <div class="col-md-4">
         <div class="why_join_us">
            <?php if($settings->getSetting('inspira.rightcolhdingtext') || $settings->getSetting('inspira.rightcolhdingdes')) { ?>
              <h3 class="custom_footer_heading"><?php echo $this->translate($settings->getSetting('inspira.rightcolhdingtext', 'WHY JOIN US?')); ?></h3>
            <?php } ?>
            <?php if($settings->getSetting('inspira.rightcolhdingdes')) { ?>
              <div class="footer_link_bottom">
                <p><?php echo $this->translate($settings->getSetting('inspira.rightcolhdingdes', 'We are a secure community with 5000+ active members who help you with your queries, post new updates and grow your network.')); ?></p>
              </div>
            <?php } ?>
            <div class="footer_social_links">   
              <?php
              echo $this->navigation()
                ->menu()
                ->setContainer($this->socialnavigation)
                ->setPartial('application/modules/Core/views/scripts/_navFontIcons.tpl')
                ->render()
              ?>
            </div>
         </div>
      </div>
   </div>
   <div class="footer_copyright_section">
      <span class="footer_copyright"><?php echo $this->translate('Copyright &copy;%s', date('Y')) ?></span>
      <?php if(!empty($this->viewer_id)) { ?>
         <?php if(Engine_Api::_()->getApi('settings', 'core')->getSetting('core.sell.info')): ?>
            <div class="footer_donotsell">
               <input type="checkbox" id="donosellinfo" onclick="donotSellInfo()" <?php if($this->viewer->donotsellinfo == 1) { ?> checked <?php } ?>> <?php echo $this->translate("Do Not Sell My Personal Information."); ?>
            </div>
         <?php endif; ?>
         <script>
            function donotSellInfo() {
               var checkBox = document.getElementById("donosellinfo");
               (scriptJquery.ajax({
               method: 'post',
               url: en4.core.baseUrl + 'core/index/donotsellinfo/',
               dataType: 'json',
               data: {
                  format: 'json',
                  donotsellinfo: checkBox.checked,
               },
               success: function(responseHTML) {
               }
               }));
               return false;
            }
         </script>
      <?php } ?>
      <?php //Languages ?>
      <?php echo $this->partial('_languages.tpl', 'core', array('languageNameList' => $this->languageNameList)); ?>
   </div>
</div>

<?php if($settings->getSetting('inspira.footer.background.image')) { ?>
  <style type="text/css">
  #global_footer{
    background-image:url('<?php echo $settings->getSetting('inspira.footer.background.image'); ?>');
  }
  </style>
<?php } ?>
