<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class  Inspira_Widget_LandingPageBannerController extends Engine_Content_Widget_Abstract {
  
  public function indexAction() {
    $this->view->allParams = $this->_getAllParams();
  }
}
