<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php $allParams = $this->allParams; ?>
<?php if(!empty($allParams['description'])) { ?>
	<p><?php echo $this->translate($allParams['description']); ?></p>
<?php } ?>
<div class="landing_page_container landing_inspira_albums">
  <div class="row justify-content-center ">
    <div class="albums_carousel_wrapper">
      <div class="albums_lp_carousel owl-carousel">
        <?php foreach($this->paginator as $item) { ?>
          <div class="col-md-12">
            <div class="landing_inspira_albums_item box_albums-1">
              <div class="albums_lp_main">
                <div class='albums_photo'>
                  <?php echo $this->htmlLink($item->getHref(), $this->itemPhoto($item, 'thumb.profile')); ?>
                  <div class="info">
                    <div class="title">
                      <?php echo $this->htmlLink($item->getHref(), $this->string()->truncate($item->getTitle(), 13)) ?>
                    </div>
                    <div class="user">
                    <?php echo $this->htmlLink($item->getOwner()->getHref(), $item->getOwner()->getTitle()); ?>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        <?php } ?>
      </div>
    </div>
  </div>
</div>
<?php $this->headScript()->appendFile($this->layout()->staticBaseUrl . 'externals/jQuery/owlcarousel/jquery.js'); ?>
<?php $this->headScript()->appendFile($this->layout()->staticBaseUrl . 'externals/jQuery/owlcarousel/owl.carousel.js'); ?>
<script type="text/javascript">
owlJqueryObject(".albums_lp_carousel").owlCarousel({
  nav:true,
  dots:false,
  margin:20,
  center:true,
  loop:true,
  autoplaySpeed: 10000,
  autoplayTimeout:1000,
  <?php 
  $orientation = ($this->layout()->orientation == 'right-to-left' ? 'rtl' : 'ltr');
  if($orientation == 'rtl') { ?>
    rtl:true,
  <?php  }?>
  responsive:{
    0:{
        items:1
    },
    768:{
        items:3
    }
  }
});
owlJqueryObject(".owl-prev").html('<i class="fa fa-angle-left"></i>');
owlJqueryObject(".owl-next").html('<i class="fa fa-angle-right"></i>');
</script>
