<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

$banners = array('' => '');
$files = Engine_Api::_()->getDbTable('files', 'core')->getFiles(array('fetchAll' => 1, 'extension' => array('gif', 'jpg', 'jpeg', 'png', 'webp', 'svg')));
foreach( $files as $file ) {
  $banners[$file->storage_path] = $file->name;
}

$headScript = new Zend_View_Helper_HeadScript();
$headScript->appendFile(Zend_Registry::get('StaticBaseUrl') . 'externals/jscolor/jscolor.js');

return array(
  
  array(
    'title' => 'Inspira Theme - Header',
    'description' => 'This widget displays the Header of website.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.header',
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Header',
    'description' => 'This widget displays the Header on the Landing Page.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-header',
  ),
  array(
    'title' => 'Inspira Theme - Footer',
    'description' => 'This widget displays the Footer of the website.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.footer',
    "autoEdit"=>false
  ),
  array(
    'title' => 'Inspira Theme - Landing Page',
    'description' => 'Displays Landing Page.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-main',
    'adminForm' => 'Inspira_Form_Admin_Widget_LandingPageMain',
    "autoEdit"=>true
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Banner',
    'description' => 'Displays the Banner on Landing Page. Requires that you have at least one banner.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-banner',
    "autoEdit" => true,
    'adminForm' => array(
      'elements' => array(
				array(
					'Text',
					'backgroundcolor',
					array(
						'class' => 'SEcolor',
						'label' => 'Choose Background color of the banner when there are no banner image.',
						'value' => '#1790bd',
					)
				),
        array(
          'Select',
          'bannerimage1',
          array(
            'label' => 'Choose the Banner Image to be shown in this widget. Image to be chosen in this widget should be first uploaded from the "Layout" >> "File & Media Manager" section.',
            'multiOptions' => $banners,
            'value' => '',
          )
        ),
        array(
          'Select',
          'bannerimage2',
          array(
            'label' => 'Choose the Banner Image to be shown in this widget. Image to be chosen in this widget should be first uploaded from the "Layout" >> "File & Media Manager" section.',
            'multiOptions' => $banners,
            'value' => '',
          )
        ),
        array(
          'Select',
          'bannerimage3',
          array(
            'label' => 'Choose the Banner Image to be shown in this widget. Image to be chosen in this widget should be first uploaded from the "Layout" >> "File & Media Manager" section.',
            'multiOptions' => $banners,
            'value' => '',
          )
        ),
        array(
          'Select',
          'bannerimage4',
          array(
            'label' => 'Choose the Banner Image to be shown in this widget. Image to be chosen in this widget should be first uploaded from the "Layout" >> "File & Media Manager" section.',
            'multiOptions' => $banners,
            'value' => '',
          )
        ),
        array(
          'Text',
          'heading',
          array(
            'label' => 'Enter heading',
          ),
          'value' => '',
        ),
        array(
          'Text',
          'description1',
          array(
            'label' => 'Enter Moving Descriptions 1',
          ),
          'value' => '',
        ),
        array(
          'Text',
          'description2',
          array(
            'label' => 'Enter Moving Descriptions 2',
          ),
          'value' => '',
        ),
        array(
          'Text',
          'description3',
          array(
            'label' => 'Enter Moving Descriptions 3',
          ),
          'value' => '',
        ),
        array(
          'Text',
          'description4',
          array(
            'label' => 'Enter Moving Descriptions 4',
          ),
          'value' => '',
        ),
      ),
    ),
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Features',
    'description' => 'This widget displays the Feature blocks on Landing Page. Edit this widget to configure features.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-features',
    'adminForm' => 'Inspira_Form_Admin_Widget_LandingPageFeatures',
    "autoEdit"=>true
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Service',
    'description' => 'This widget displays the Services blocks on Landing Page. Edit this widget to configure service.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-service',
    'adminForm' => 'Inspira_Form_Admin_Widget_LandingPageServices',
    "autoEdit" => true
  ),
  array(
    'title' => 'Inspira Theme - Landing Page App',
    'description' => 'This widget displays the Feature blocks on Landing Page. Edit this widget to configure App.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-app',
    'adminForm' => array(
      'elements' => array(
        array(
          'Text',
          'heading',
          array(
            'label' => 'Enter Heading',
          ),
        ),
        array(
          'Text',
          'description',
          array(
            'label' => 'Enter Description',
          ),
        ),
        array(
          'Text',
          'androidapplink',
          array(
            'label' => 'Enter Android App Link',
          ),
        ),
        array(
          'Text',
          'iosapplink',
          array(
            'label' => 'Enter iOS App Link',
          ),
        ),
      )
    ),
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Groups',
    'description' => 'This widget displays the Feature blocks on Landing Page. Edit this widget to configure Groups.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-groups',
    //'isPaginated' => true,
    'defaultParams' => array(
      'title' => 'Popular Groups',
    ),
    'adminForm' => array(
      'elements' => array(
        array(
          'Radio',
          'popularType',
          array(
            'label' => 'Popular Type',
            'multiOptions' => array(
              'view' => 'Views',
              'member' => 'Members',
            ),
            'value' => 'view',
          )
        ),
        array(
          'Text',
          'description',
          array(
            'label' => 'Enter Description',
          ),
        ),
      )
    ),
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Music',
    'description' => 'This widget displays the Feature blocks on Landing Page. Edit this widget to configure Music.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-music',
    //'isPaginated' => true,
    'defaultParams' => array(
      'title' => 'Popular Playlists',
    ),
    'adminForm' => array(
      'elements' => array(
        array(
          'Text',
          'description',
          array(
            'label' => 'Enter Description',
          ),
        ),
        array(
          'Radio',
          'popularType',
          array(
            'label' => 'Popular Type',
            'multiOptions' => array(
              'play' => 'Plays',
              'view' => 'Views',
              'comment' => 'Comments',
            ),
            'value' => 'play',
          )
        ),
      )
    ),
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Video',
    'description' => 'This widget displays the Feature blocks on Landing Page. Edit this widget to configure Music.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-videos',
    "autoEdit" => false,
    'defaultParams' => array(
      'title' => 'Popular Videos',
    ),
    'adminForm' => array(
      'elements' => array(
        array(
          'Text',
          'description',
          array(
            'label' => 'Enter Description',
          ),
        ),
        array(
          'Radio',
          'popularType',
          array(
            'label' => 'Popular Type',
            'multiOptions' => array(
              'view' => 'Views',
              'comment' => 'Comments',
            ),
            'value' => 'view',
          )
        ),
      )
    ),
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Albums',
    'description' => 'This widget displays the Feature blocks on Landing Page. Edit this widget to configure Album.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-albums',
    "autoEdit"=>false,
    'defaultParams' => array(
      'title' => 'Popular Albums',
    ),
    'adminForm' => array(
      'elements' => array(
        array(
          'Radio',
          'popularType',
          array(
            'label' => 'Popular Type',
            'multiOptions' => array(
              'view' => 'Views',
              'comment' => 'Comments',
            ),
            'value' => 'comment',
          )
        ),
        array(
          'Text',
          'description',
          array(
            'label' => 'Enter Description'
          )
        ),
      )
    ),
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Events',
    'description' => 'This widget displays the Feature blocks on Landing Page. Edit this widget to configure Events.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-events',
    "autoEdit" => true,
    'defaultParams' => array(
      'title' => 'Popular Events'
    ),
    'adminForm' => array(
      'elements' => array(
        array(
          'Text',
          'title',
          array(
            'label' => 'Title'
          )
        ),
        array(
          'Text',
          'description',
          array(
            'label' => 'Enter Description',
          ),
        ),
        array(
          'Radio',
          'popularType',
          array(
            'label' => 'Popular Type',
            'multiOptions' => array(
              'view' => 'Views',
              'member' => 'Members',
            ),
            'value' => 'member',
          )
        ),
      ),
    )
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Counter',
    'description' => 'This widget displays the Feature blocks on Landing Page. Edit this widget to configure Counter.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-counter',
    "autoEdit" => true,
    'adminForm' => array(
        'elements' => array(
            array(
              'Text',
              'heading',
              array(
                'label' => 'Enter Heading.',
              ),
            ),
            array(
              'Text',
              'description',
              array(
                'label' => 'Enter Description',
              ),
            ),
            array(
              'Select',
              'backgroundimage',
              array(
                'label' => 'Choose the Background Image to be shown in this widget. Image to be chosen in this widget should be first uploaded from the "Layout" >> "File & Media Manager" section.',
                'multiOptions' => $banners,
                'value' => '',
              )
            ),
            array(
              'Select',
              'rightmage',
              array(
                'label' => 'Choose the right side Image to be shown in this widget. Image to be chosen in this widget should be first uploaded from the "Layout" >> "File & Media Manager" section.',
                'multiOptions' => $banners,
                'value' => '',
              )
            ),
            array(
              'Text',
              'counter1',
              array(
                'label' => 'Enter Counter - 1 Value.',
              ),
              'value' => '450',
            ),
            array(
              'Text',
              'counter1text',
              array(
                'label' => 'Enter Counter - 1 Text.',
              ),
              'value' => 'Members',
            ),
            array(
              'Text',
              'counter2',
              array(
                'label' => 'Enter Counter - 2 Value.',
              ),
              'value' => '500',
            ),
            array(
              'Text',
              'counter2text',
              array(
                'label' => 'Enter Counter - 2 Text.',
              ),
              'value' => 'Directories',
            ),
            array(
              'Text',
              'counter3',
              array(
                'label' => 'Enter Counter - 3 Value.',
              ),
              'value' => '200',
            ),
            array(
              'Text',
              'counter3text',
              array(
                'label' => 'Enter Counter - 3 Text.',
              ),
              'value' => 'Products',
            ),

            array(
              'Text',
              'counter4',
              array(
                'label' => 'Enter Counter - 4 Value.',
              ),
              'value' => '100',
            ),
            array(
              'Text',
              'counter4text',
              array(
                'label' => 'Enter Counter - 4 Text.',
              ),
              'value' => 'Prayers',
            ),
        ),
    ),
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Blogs',
    'description' => 'This widget displays the Blogs on Landing Page.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-blogs',
    "autoEdit"=>true,
    'defaultParams' => array(
      'title' => 'Popular Blog Entries'
    ),
    'adminForm' => array(
      'elements' => array(
        array(
          'Text',
          'title',
          array(
            'label' => 'Title'
          )
        ),
        array(
          'Text',
          'description',
          array(
            'label' => 'Enter Description',
          ),
        ),
        array(
          'Radio',
          'popularType',
          array(
            'label' => 'Popular Type',
            'multiOptions' => array(
              'view' => 'Views',
              'comment' => 'Comments',
            ),
            'value' => 'comment',
          )
        ),
      ),
    )
  ),
  array(
    'title' => 'Inspira Theme - Landing Page Member',
    'description' => 'This widget displays the Members on Landing Page.',
    'category' => 'Inspira Theme',
    'type' => 'widget',
    'name' => 'inspira.landing-page-members',
    "autoEdit"=>true,
    'adminForm' => array(
      'elements' => array(
        array(
          'Radio',
          'popularType',
          array(
            'label' => 'Popular Type',
            'multiOptions' => array(
                'view' => 'Views',
                'member' => 'Friends',
            ),
            'value' => 'view',
          )
        ),
      ),
    )
  ),
);
