<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php $allParams = $this->allParams; ?>
<?php if(!empty($allParams['description'])) { ?>
	<p><?php echo $this->translate($allParams['description']); ?></p>
<?php } ?>
<div class="lp_inspira_service">
  <div class="container">
		<div class="row lp_inspira_service_wrapper">
			<?php for($i=1;$i<=8;$i++) { ?>
				<?php if(!empty($allParams['icon'.$i]) || !empty($allParams['heading'.$i]) || !empty($allParams['description'.$i])) { ?>
					<div class="col-md-3">
						<div class="lp_inspira_service_item  wow zoomIn">
							<div class="lp_inspira_service_top">
								<?php if(!empty($allParams['icon'.$i])) { ?>
									<div class="lp_inspira_service_icon">
										<i class="<?php echo $allParams['icon'.$i]; ?>"></i>
									</div>
								<?php } ?>
								<?php if(!empty($allParams['heading'.$i])) { ?>
									<h3 class="title"><?php echo $this->translate($allParams['heading'.$i]); ?></h3>
								<?php } ?>
								<?php if(!empty($allParams['description'.$i])) { ?>
									<p class="des"><?php echo $this->translate($allParams['description'.$i]); ?></p>
								<?php } ?>
							</div>
						</div>
					</div>
				<?php } ?>
			<?php } ?>
		</div>
	</div>
</div>
