<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<?php
   $settings  = Engine_Api::_()->getApi('settings', 'core');
   if(empty($this->Wimage)){
     $img = "application/themes/inspira/images/landing-banner.jpg";
   } else{
     $img = Engine_Api::_()->core()->getFileUrl($this->Wimage);
   }
   ?>
<div class="banner_landing_main_section">
   <div class="banner_landing_main_inner">
      <div class="banner_main_left" style="background-image: url(<?php echo $img; ?>);"></div>
      <div class="banner_main_right">
         <div>
           <?php // echo $this->form->setAttrib('class', 'global_form_box')->render($this) ?>
         </div>
         <div class="landing-banner_right_inner">

         <?php if(engine_in_array('logo',$this->options)){ ?>
          <?php echo $this->content()->renderWidget("core.menu-logo",array("logo"=>$this->logo)); ?>
         <?php } ?>

          <h2><?php echo $this->translate($this->description); ?></h2>
          <div class="btn_group">
            <a href="login" class="btn login_btn"><span><?php echo $this->translate("Sign In");?></span></a>
            <a href="signup" class="btn signup_btn"><span><?php echo $this->translate("Sign Up");?></span></a>
         </div>
         <?php if(('none' != $settings->getSetting('core_facebook_enable', 'none') && $settings->core_facebook_secret) || $settings->core_twitter_secret) { ?>
          <div class="btns_sep">
            <span class="line"></span>
            <span class="txt"><?php echo $this->translate("or");?></span>
            <span class="line"></span>
          </div>
          <div class="btn_group social_btns">
            <?php if( 'none' != $settings->getSetting('core_facebook_enable', 'none') && $settings->core_facebook_secret ) { ?>
              <?php $href = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('module' => 'user', 'controller' => 'auth', 'action' => 'facebook'), 'default', true); ?>
              <a class="btn facebook_btn" href="<?php echo $href; ?>"><i class="fab fa-facebook-f"></i><span><?php echo $this->translate("Login with Facebook");?></span></a>
            <?php } ?>
            <?php if($settings->core_twitter_secret) { ?>
              <?php $href = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('module' => 'user', 'controller' => 'auth', 'action' => 'twitter'), 'default', true); ?>
              <a class="btn twitter_btn" href="<?php echo $href; ?>"><i class="fab fa-twitter"></i><span><?php echo $this->translate("Login with X");?></span></a>
            <?php } ?>
          </div>
         <?php } ?>
      </div>
    </div>
   </div>
</div>
<script type="application/javascript">
   scriptJquery('#user_form_login').find('input[type="email"]').attr('placeholder','<?php echo $this->translate("Email Address"); ?>');
   scriptJquery('#user_form_login').find('input[type="password"]').attr('placeholder','<?php echo $this->translate("Password"); ?>');
</script>
