<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php $allParams = $this->allParams; ?>
<div class="container lp_inspira_app_wrapper">
	<div class="row ">
		<?php if(!empty($allParams['heading']) || !empty($allParams['description'])) { ?>
			<div class="col-md-7">
				<div class="lp_app_left">
					<h3><?php echo $this->translate($allParams['heading']); ?></h3>
					<p><?php echo $this->translate($allParams['description']); ?></p>
				</div>
			</div>
		<?php } ?>
		<?php if(!empty($allParams['androidapplink']) || !empty($allParams['iosapplink'])) { ?>
			<div class="col-md-5">
				<div class="lp_app_right">
					<a href="<?php echo $this->translate($allParams['iosapplink']); ?>" target="_blank"><img src="application/modules/Inspira/externals/images/app1.png"></a>
					<a href="<?php echo $this->translate($allParams['androidapplink']); ?>"  target="_blank"><img src="application/modules/Inspira/externals/images/app2.png"></a>
				</div>
			</div>
		<?php } ?>
	</div>
</div>
