/*Common Layout*/
.inspira_landingpage_1 #global_content,
.inspira_landingpage_1 .layout_middle{
	overflow:inherit !important;
}
.inspira_landingpage_1 #global_content .layout_middle{
	padding:0;
}
/*Footer*/
.inspira_landingpage_1 #global_footer{
	padding-top:90px;
}
body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container{
  padding:60px 0;
	margin:0;
	border:none;
}
body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container > h3,
.custom_heading{
	font-size:220%;
	font-weight:500;
	padding:0;
	margin:0;
	margin-bottom:30px;
	position:relative;
	border:none;
  text-align:center;
	background:transparent;

}
body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container > h3:after,
.custom_heading:after{
	position:absolute;
	content:'';
	height:5px;
	width:15px;
	bottom:-15px;
	right:0;
	left:-40px;
	margin:auto;
  border-radius:1px;
}
body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container > h3:before,
.custom_heading:before{
	position:absolute;
	content:'';
	height:5px;
	width:110px;
	bottom:-15px;
	right:0;
	left:0;
	margin:auto;
	border-radius:2px;
}
body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container > p,
.custom_des{
	width:50%;
	margin:auto;
	line-height:30px;
	text-align:center;
}
body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container .viewlink{
	text-align:center;
	display:block;
	float:none;
	padding:12px 20px;
	margin:30px auto 0;
  width:150px;
	border-radius:50px;
	font-weight:600;
	font-size:16px;
	border:2px solid;
	transition:0.5s;
}
body.inspira_landingpage_1.generic_layout_container.layout_middle .generic_layout_container:nth-child(2n+2){
	background-image:url(~/application/themes/inspira/images/section-bg.png) ;
}
/*Banner Start*/
.generic_layout_container.layout_inspira_landing_page_banner{
	padding:0 !important;
	border:0px;
}
.generic_layout_container.layout_inspira_landing_page_banner{
	margin:0;
}
.landing_banner{
	width:100%;
	display:flex;
	margin:auto;
	height:600px;
	position:relative;
	align-items:center;
	justify-content:center;
	background-size:cover;
	background-repeat:no-repeat;
}
.landing_banner_img,
.landing_banner_img > div{
	position:absolute;
	left:0;
	top:0;
	width:100%;
	height:100%;
}
.landing_banner_img > div{
	position:absolute;
	opacity:0;
	background-position:center;
	background-repeat:no-repeat;
	background-size:cover;
}
.landing_banner_img > div img{
	height:100%;
	width:100%;
}
.landing_banner::after{
  width:100%;
  height:100%;
  top:0;
  left:0;
  content:'';
  background-color:rgba(0, 0, 0, .3);
  position:absolute;
}
.landing_banner_content{
  text-align:center;
  display:block;
  z-index:1;
  position:relative;
  width:90%;
  margin:auto;
}
[dir="rtl"] .landing_banner_content{
text-align:center;
}
.landing_banner_content h1{
	font-size:50px;
	font-weight:500;
	margin-bottom:20px;
}
.landing_banner_content p,
.landing_banner_content p span{
	font-size:120%;;
	line-height:35px;
	text-align:center;
}

/*Banner End*/

.landing_page_container{
	max-width:1200px;
	margin:0 auto;
	padding:0 15px
}
.landing_page_container *{
	box-sizing:border-box;
}
.landing_page_container .row{
	display:flex;
	justify-content:center;
	flex-wrap:wrap;
	margin-left:-15px;
	margin-right:-15px;
}
.landing_page_container .row > div{
	padding:0 15px
}

/*Features Start*/
.layout_inspira_landing_page_features{
	position:relative;
	z-index:1;
}
.layout_inspira_landing_page_features::before{
	content:'';
	position:absolute;
	left:0;
	bottom:0;
	width:100%;
	height:100%;
	background-image:url(~/application/themes/inspira/images/feautersleft.png);
	background-size:450px;
	background-repeat:no-repeat;
	background-position:left bottom;
	z-index:-1;
}
.layout_inspira_landing_page_features:after{
	content:'';
	position:absolute;
	right:0;
	top:0;
	width:100%;
	height:100%;
	background-image:url(~/application/themes/inspira/images/feautersright.png);
	background-size:450px;
	background-repeat:no-repeat;
	background-position:right top;
	z-index:-1;
}
.inspira_features_wrapper{
	width:100%;
	text-align:center;
}
.inspira_features_wrapper > p{
	text-align:center;
}
.inspira_features_block{
	margin-top:50px;
}
.inspira_features_block .row{
	align-items:center;
}
.inspira_features_block .inspira_feature_bg figure{
	margin:0;
	position:relative;
	display:flex;
	align-items:center;
	justify-content:center;
}
.inspira_features_block .inspira_feature_bg a{
	position:absolute;
	width:70px;
	height:70px;
	line-height:70px;
	font-size:25px;
	left:0;
	right:0;
	margin:auto;
	border-radius:50%;
	text-align:center;
	z-index:9;
	transition:.5s;
}
.inspira_features_block .inspira_feature_bg a i{
	margin-left:5px;
}
.inspira_features_block .inspira_feature_bg img{
	max-width:100%;
	position:relative;
	z-index:9;
	border-radius:10px;
	overflow:hidden;
}
.inspira_features_block .inspira_feature_bg figure::after{
	position:absolute;
	content:'';
	width:90%;
	height:100%;
	bottom:-8px;
	border-radius:10px;
	transition:0.3s;
	left:10px;
}
.inspira_features_block .inspira_feature_bg figure:hover::after{
	left:-10px;
	bottom:0px;
	left:15px;
  bottom:-3px;
  width:92%;
}
.inspira_feature_item{
	display:flex;
	position:relative;
	margin:15px 0;
	float:left;
	width:100%;
}
.inspira_feature_item .inspira_feature_item_icon{
	margin-right:25px;
}
[dir="rtl"] .inspira_feature_item .inspira_feature_item_icon{
	 margin-right:0px;
	 margin-left:25px;
 }
 .inspira_feature_item_icon i.icon_feature{
	width:40px;
	font-size:40px;
	line-height:40px;
 }
.inspira_feature_item_cont h3{
	font-size:120%;
	margin-bottom:5px;
	font-weight:bold;
	padding:0;
}
.inspira_feature_item_cont p{
	margin:0;
}
/*Features End*/

/*events Start */
.landing_inspira_events{
	margin-top:90px;
}
.landing_inspira_events_item{
	margin-bottom:30px;
	width:100%;
}
.landing_inspira_events .events_photo{
	position:relative;
	transition:0.5s;
	transform:scale(1.00);
	display:flex;
  align-items:center;
  justify-content:center;
}
.landing_inspira_events .events_photo > a{
	display:block;
}
.landing_inspira_events .events_photo > a > span{
	width:250px;
	height:250px;
	border:6px solid;
	margin:auto;
  border-radius:50%;
	position:relative;
	transition:.5s;
}
.landing_inspira_events .events_photo > a > span:after{
	content:'';
	width:100%;
	height:100%;
	background-color:rgba(0, 0, 0, .40);
	position:absolute;
	left:0;
	top:0;
	border-radius:50%;
}
.landing_inspira_events .events_photo:hover{
	transform:scale(1.01);
}
.landing_inspira_events .info{
	position:absolute;
	left:0;
	right:0;
	margin:auto;
	width:180px;
}
.landing_inspira_events .title > a{
	font-size:120%;;
	font-weight:600;
	display:block;
	text-transform:capitalize;
	white-space:nowrap;
  text-overflow:ellipsis;
  overflow:hidden;
	text-align:center;
}
.landing_inspira_events_item .events_stats{
	left:0;
	right:0;
	top:-20px;
	margin:auto;
	position:absolute;
	width:100%;
	display:flex;
	align-content:center;
	justify-content:center;
	-webkit-transition:all 800ms ease 0s;
	-moz-transition:all 800ms ease 0s;
	-o-transition:all 800ms ease 0s;
	transition:all 800ms ease 0s;
}
.landing_inspira_events_item:hover .events_stats{
	top:-40px;
	opacity:0;
}
.landing_inspira_events_item .events_stats p{
	position:relative;
	display:flex;
	flex-direction:column;
	justify-content:center;
	align-items:center;
	margin:0 10px;
	width:45px;
	height:45px;
	border-radius:50%;
}
.landing_inspira_events_item .events_stats p.list_comments{
	left:-30px;
	margin-top:50px;
}
.landing_inspira_events_item .events_stats p.list_views{
	right:-30px;
	margin-top:50px;
}
[dir="rtl"] .landing_inspira_events_item .events_stats p.list_comments{
	left:auto;
	right:-30px;
}
[dir="rtl"] .landing_inspira_events_item .events_stats p.list_views{
	right:auto;
	left:-30px;
}
/*events End */

/*Albums Start */
.landing_inspira_albums{
	margin-top:50px;
	position:relative;
}
.landing_inspira_albums .albums_photo{
	overflow:hidden;
	position:relative;
}
.landing_inspira_albums .albums_photo > a{
	overflow:hidden;
	position:relative;
	display:block;
	border-radius:5px;
}
.albums_carousel_wrapper .owl-stage{
	display:flex;
}
.albums_carousel_wrapper .owl-stage-outer{
	position:relative;
	overflow:hidden;
}
.albums_carousel_wrapper .owl-stage-outer .owl-item{
  display:flex;
	align-items:center;
}
.albums_carousel_wrapper .owl-item .landing_inspira_albums_item{
	transform:scale(0.8);
	width:100% 	;
}
.albums_carousel_wrapper .owl-item.center .landing_inspira_albums_item{
	transform:scale(1.20);
}
.landing_inspira_albums .albums_photo > a > img{
	width:100%;
	max-width:100%;
	max-height:100%;
	height:280px;
	object-fit:cover;
	border:none;
}
.albums_carousel_wrapper .owl-item.center .albums_photo > a >  img{
	height:340px;
}
.landing_inspira_albums_item .info{
	display:flex;
	align-items:center;
	justify-content:center;
	flex-direction:column;
	padding:10px;
	height:100%;
	position:absolute;
	left:0;
	right:0;
	margin:auto;
	top:0;
	transition:0.8s;
	bottom:0%;
	width:100%;
	transform:scale(0);
}
.landing_inspira_albums_item .info:after{
	content:'';
	position:absolute;
	left:0;
	right:0;
	bottom:0%;
	width:100%;
	height:100%;
	opacity:.7;
	transform:scale(0);
}
.landing_inspira_albums_item:hover .info,
.landing_inspira_albums_item:hover .info:after,
.albums_carousel_wrapper .owl-item.center .landing_inspira_albums_item .info:after,
.albums_carousel_wrapper .owl-item.center .landing_inspira_albums_item .info{
	transform:scale(1.0);
}
.landing_inspira_albums_item .info .title{
	width:100%;
	z-index:1;
	position:relative;
	display:block;
}
.landing_inspira_albums_item .info .title a{
	font-size:130%;
	font-weight:600;
	display:block;
	text-transform:capitalize;
	width:100%;
	text-align:center;
	white-space:nowrap;
	overflow:hidden;
	text-overflow:ellipsis;
}
.landing_inspira_albums_item .user{
	z-index:1;
	position:relative;
}
.albums_carousel_wrapper .owl-nav > div{
	position:absolute;
	width:45px;
	height:45px;
	border-radius:50px;
	text-align:center;
	line-height:45px;
	font-size:28px;
	top:50%;
	transform:translate(0 , -50%);
	cursor:pointer;
	border:1px solid;
	display:flex;
	align-items:center;
	justify-content:center;
}
.albums_carousel_wrapper .owl-nav > .owl-next{
	right:-10px;
}
.albums_carousel_wrapper .owl-nav > .owl-prev{
	left:-10px;
}
/*Alubms End*/

/*Counter Start*/ 
.generic_layout_container.layout_inspira_landing_page_counter{
	background-size:cover;
	background-repeat:no-repeat;
	position:relative;
	padding:100px 0 !important;
}
.generic_layout_container.layout_inspira_landing_page_counter::after{
	position:absolute;
	content:'';
	top:0;
	left:0;
	width:100%;
	height:100%;
	background-color:rgba(0, 0, 0, .70);
}
.landing_inspira_counter{
	position:relative;
	z-index:1;
}
.landing_page_container .row{
  align-items:center;
}
.counter_left{
	padding-right:70px;
	position:relative;
	z-index:1;
}
[dir="rtl"] .counter_left{
	padding-right:0px;
	padding-left:70px;
}
.counter_left > h3,
.counter_left > p{
	text-align:left;
	width:100%;
}
.counter_left > p{
	font-size:120%;
}
.landing_inspira_counter .custom_heading::before{
	right:auto;
}
.landing_inspira_counter .custom_heading::after{
	right:auto;
	left:20px;
}
.landing_inspira_counter_box{
	position:relative;
	z-index:1;
	text-align:center;
	display:flex;
	flex-wrap:wrap;
	justify-content:start;
	align-items:center;
	margin:15px -15px 0;
}
.landing_inspira_counter_box li{
	width:44%;
	position:relative;
	margin:15px;
	border-radius:10px;
	padding:25px;
	z-index:1;
}
.landing_inspira_counter_box li::after{
	content:'';
	position:absolute;
	left:15px;
	top:15px;
	background:url(images/counter-after.png);
	width:100%;
	height:100%;
	background-size:45px;
	background-repeat:no-repeat;
	z-index:-1;
}
[dir="rtl"] .landing_inspira_counter_box li::after{
	left:80%;
}
.landing_inspira_counter_detail h3{
	font-size:35px;
	font-weight:700;
	margin:0 0 5px;
	padding:0;
}
.landing_inspira_counter_detail p{
	font-size:22px;
	font-weight:500;
	margin:0;
}
.counter_right img{
	width:100%;
	border-radius:130px 0 130px 0;
	transition:0.5s;
	overflow:hidden;
}
.counter_right img:hover{
	border-radius:0px 130px 0px 130px;
}
/*Counter End*/

/*Video Start*/ 
.landing_inspira_videos_item{
	margin-top:30px;
	width:100%;
}
.landing_inspira_videos .videos_photo{
	overflow:hidden;
	position:relative;
	border-radius:10px
}
.landing_inspira_videos .videos_photo .bg_item_photo{
	border-radius:0;
	width:100%;
	height:280px;
	background-position:center;
	border:none;
}
.landing_inspira_videos .videos_photo > a{
	overflow:hidden;
	border-radius:10px;
	position:relative;
	transition:0.5s;
	transform:scale(1.00);
	display:block;
}
.landing_inspira_videos .videos_photo:hover > a{
	transform:scale(1.01);
}
.landing_inspira_videos .videos_play_icon{
	position:absolute;
	right:0;
	left:0;
	top:0;
	margin:auto;
	text-align:center;
	height:100%;
	display:flex;
	justify-content:center;
	align-items:center;
	transition:0.5s;
}
.landing_inspira_videos .videos_play_icon a{
	width:50px;
	height:50px;
	border-radius:50px;
	display:flex;
	align-items:center;
	justify-content:center;
	font-size:120%;;
	transition:0.5s;
	border:2px solid;
	z-index:1;
}
.landing_inspira_videos .videos_photo img{
	width:100%;
}
.landing_inspira_videos .info{
	padding:10px 15px;
  text-align:left;
	flex:1;
	display:flex;
	flex-direction:column;
	z-index:1;
	position:absolute;
	width:100%;
	right:0;
	left:0;
	bottom:0;
	transition:0.5s;
}
.landing_inspira_videos .videos_photo:hover .info{
	opacity:0;
	bottom:-50%;
}
.landing_inspira_videos .title > a{
	font-size:120%;
	font-weight:600;
	display:block;
	text-transform:capitalize;
	white-space:nowrap;
  text-overflow:ellipsis;
  overflow:hidden;
}
/*Video End*/

/*Music Start*/
.landing_inspira_music_item{
	margin-top:30px;
	width:100%;
}
.landing_inspira_music .music_photo{
	overflow:hidden;
	position:relative;
	border-radius:10px 10px 0 0;
}
.landing_inspira_music .music_photo span{
	height:300px;
	border:none;
}
.landing_inspira_music .music_photo span:before{
	font-size:100px;
}
.landing_inspira_music .music_photo > a{
	overflow:hidden;
	border-radius:10px;
	position:relative;
	transition:0.5s;
	transform:scale(1.00);
	display:block;
}
.landing_inspira_music .music_photo:hover > a{
	transform:scale(1.01);
}
.landing_inspira_music .music_play_icon{
	position:absolute;
	right:0;
	left:0;
	top:0;
	margin:auto;
	text-align:center;
	height:100%;
	display:flex;
	justify-content:center;
	align-items:center;
	background:rgba(0, 0, 0, .10);
	transition:0.5s;
	opacity:1;
}
.landing_inspira_music .music_play_icon a{
	width:60px;
	height:60px;
	border-radius:50px;
	display:flex;
	align-items:center;
	justify-content:center;
	font-size:120%;;
	transition:0.5s;
	border:1px solid ;
}
.landing_inspira_music .music_photo img{
	width:100%;
}
.landing_inspira_music .info{
	padding:10px 15px;
	box-shadow:0 1px 3px rgba(0, 0, 0, 0.2);
	position:relative;
	text-align:center;
	display:flex;
	flex-direction:column;
	border-radius:10px;
	z-index:1;
	margin:-40px 20px 0px;
}
.landing_inspira_music .title > a{
	font-size:120%;
	font-weight:600;
	display:block;
	text-transform:capitalize;
	white-space:nowrap;
  text-overflow:ellipsis;
  overflow:hidden;
	text-align:center;
}
.landing_inspira_music .info .user{
	text-align:center;
}
/*Music End*/

/*Groups Start*/
.landing_inspira_groups_item{
	margin-top:30px;
	width:100%;
}
.landing_inspira_groups_item .groups_photo span{
	height:300px;
	border:none;
}
.landing_inspira_groups .groups_photo{
	overflow:hidden;
	border-radius:10px;
	position:relative;
	transition:0.5s;
}
.landing_inspira_groups .groups_photo img{
	width:100%;
}
.landing_inspira_groups .info{
	padding:15px;
	position:absolute;
	text-align:left;
	display:flex;
	flex-direction:column;
	border-radius:0px 0 0 10px;
	z-index:1;
	width:80%;
	bottom:0;
}
[dir="rtl"] .landing_inspira_groups .info{
	border-radius:10px 0 0 0px;
}
.landing_inspira_groups .info .member a{
	font-weight:500;
}
.landing_inspira_groups .title > a{
	font-size:120%;;
	font-weight:600;
	display:block;
	text-transform:capitalize;
	white-space:nowrap;
  text-overflow:ellipsis;
  overflow:hidden;
	margin:1px 0;
}
.landing_inspira_groups .info .category a{
	font-weight:bold;
}
/*Groups End*/

/*Blog Start*/
.landing_inspira_blogs_item{
	margin-top:40px;
	width:100%;
}
.landing_inspira_blogs .blogs_lp_main{
	background:transparent;
	box-shadow:inherit;
	display:flex;
	flex-direction:column;
	height:100%;
	position:relative;
	overflow:hidden;
}
.landing_inspira_blogs .blogs_photo{
	overflow:hidden;
	border-radius:10px;
	position:relative;
	transition:0.5s;
	transform:scale(1.00);
}
.landing_inspira_blogs .blogs_photo .bg_item_photo{
	border-radius:0;
	width:100%;
	height:400px;
	background-position:center;
	border:none;
	position:relative;
}
.landing_inspira_blogs .blogs_photo .bg_item_photo::after{
	content:'';
	position:absolute;
	left:0;
	right:0;
	margin:auto;
	width:100%;
	height:100%;
	background-color:rgba(0, 0, 0, .40);
}
.landing_inspira_blogs .blogs_photo:hover{
	transform:scale(1.01);
}
.landing_inspira_blogs .blogs_photo img{
	width:100%;
}
.landing_inspira_blogs_item .date_box{
	position:absolute;
	left:20px;
	top:20px;
	z-index:1;
	text-align:center;
	display:flex;
	align-items:center;
	justify-content:center;
	border-radius:2px;
	padding:10px;
	font-weight:600;
}
[dir="rtl"] .landing_inspira_blogs_item .date_box{
	left:auto;
	right:20px;
}
.landing_inspira_blogs_item .date_box span{
	padding:0 2px;
}
.landing_inspira_blogs .info{
	padding:15px;
  text-align:left;
	display:flex;
	flex-direction:column;
	position:absolute;
  bottom:0;
  z-index:1;
	width:100%;
}
.landing_inspira_blogs .title > a{
	font-size:120%;
	font-weight:600;
	display:block;
	text-transform:capitalize;
	white-space:nowrap;
  text-overflow:ellipsis;
  overflow:hidden;
}
/*Blog End*/

/*Member Start*/
.landing_page_member .member_lp_carousel{
	position:relative;
	overflow:hidden;
  width:98vw;
	margin-inline:auto;
}
.landing_page_member .owl-stage-outer{
	overflow:hidden;
	margin-top:40px;
}
.landing_page_member .owl-stage{
	display:flex;
}
.inspira_member_item{
	width:240px;
	padding:5px;
}
.landing_page_member .owl-nav > div{
	position:absolute;
	width:45px;
	height:45px;
	border-radius:45px;
	text-align:center;
	line-height:45px;
	font-size:28px;
	top:50%;
	transform:translate(0 , -50%);
	cursor:pointer;
	border:1px solid;
	display:flex;
	align-items:center;
	justify-content:center;
}
.landing_page_member .owl-nav > .owl-prev{
	left:5px;
}
.landing_page_member .owl-nav > .owl-next{
	right:5px;
}
.landing_page_member .owl-nav > div.disabled{
	display:none;
}
.landing_page_member .inspira_member_box{
	position:relative;
}
.landing_page_member .inspira_member_box > a{
  border:none;
	display:block;
}
.landing_page_member .inspira_member_box .bg_item_photo{
	border:none;
	background-size:cover !important;
}
.landing_page_member .inspira_member_box  > a{
  transition:.5s;
  width:100%;
	height:200px;
	margin:auto;
	overflow:hidden;
}
.landing_page_member .info{
	text-align:center;
	padding:10px;
	margin:auto;
	width:100%;
	display:flex;
	flex-direction:column;
	align-items:center;
	justify-content:center;
	transition:0.5s;
}
.landing_page_member .inspira_member_box .name > a{
  font-size:120%;
	font-weight:600;
	text-align:center;
	display:block;
	text-transform:capitalize;
}
.landing_page_member .inspira_member_box .info .friends{
	text-align:center;
}
.inspira_member_box img{
	max-width:100%;
}
/*Member end*/
body.inspira_landingpage_1 #global_footer{
	margin-top:0;
}
/*Service*/
.layout_inspira_landing_page_service{
	background-image:url(~/application/themes/inspira/images/service.png) !important;
	background-repeat:no-repeat !important;
	background-position:center !important;
	background-attachment:fixed !important;
	background-size:cover !important;
}
.lp_inspira_service_wrapper{
	margin-top:10px;
	margin-bottom:40px;
}
.lp_inspira_service_item{
	margin-top:15px;
	display:flex;
	align-content:center;
	height:100%;
}
.lp_inspira_service_top{
	width:100%;
	padding:20px;
	border-radius:5px;
	box-shadow:0 0px 5px rgba(0, 0, 0, 0.1);
	margin-top:25px;
	transition:0.5s;
}
.lp_inspira_service_icon{
	width:60px;
	height:60px;
	border-radius:50%;
	display:flex;
	align-content:center;
	justify-content:center;
	border:1px solid ;
}
.lp_inspira_service_icon i{
	font-size:30px;
	display:flex;
	align-items:center;
	justify-content:center;
}
.lp_inspira_service_item .title{
	font-size:120%;
	padding:0;
	margin:10px 0;
	transition:.5s;
}
.lp_inspira_service_item .des{
	margin:0;
	transition:.5s;
}
/*App*/
.generic_layout_container.layout_inspira_landing_page_app{
	padding-bottom:0 !important;
}
.lp_inspira_app_wrapper{
	background-image:url(~/application/themes/inspira/images/app.png);
	padding:50px 30px;
	border-radius:5px;
	background-size:cover;
	background-position:center;
	background-repeat:no-repeat;
	margin-bottom:-55px;
	position:relative;
	z-index:2;
}
.lp_inspira_app_wrapper .row{
	align-items:center;
}
.lp_inspira_app_wrapper h3{
	font-weight:600;
	font-size:220%;
	padding:0;
	margin:0 0 10px;
}
.lp_inspira_app_wrapper p{
	font-size:120%;
	margin:0px;
}
.lp_app_right{
	display:flex;
	align-content:center;
	justify-content:flex-end;
}
.lp_app_right img{
	padding:5px;
	max-width:100%;
}
@media (max-width:1199px){
	/*Custom Heading*/
	body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container > p,
	.inspira_features_wrapper > p,
	.custom_des{
		width:100%;
		padding:0 15px;
	}
	.albums_carousel_wrapper .owl-nav > .owl-prev{
		left:0;
	}
	.albums_carousel_wrapper .owl-nav > .owl-next{
    right:0 !important;
   }

}
@media (max-width:1024px){
  .landing_inspira_events .row > div{
    width:33%;
  } 
	/*user*/
	.inspira_member_item{
    width:200px;
  }
	.landing_page_member .inspira_member_box > a{
		height:190px;
	}
}
@media (min-width:992px){
  body.inspira_landingpage_1 #global_wrapper{
    margin-top:0 !important;
  }
}
@media (max-width:991px){
/*Banner*/
  .landing_banner_content h1{
    font-size:32px;
  }
  .landing_banner_content p{
    font-size:16px;
    line-height:28px;
  }
  .landing_banner{
    padding:20px 0;
		height:500px;
  }
  .landing_banner_content{
    width:100%;
  }
  /*Features*/
  .inspira_features > div{
    margin-top:0px;
  }
  .inspira_features .inspira_features_item{
    margin-top:90px;
    width:50%
  }
	/*Counter*/
	.landing_inspira_counter_box li{
    width:42%;
	}
	.landing_inspira_counter_detail h3{
		font-size:30px;
	}
	.landing_inspira_counter_detail p{
		font-size:120%;;
	}
	[dir="rtl"] .landing_inspira_counter_box li::after{
    left:70%;
  }
	/*Counter*/
	/*Events*/
	.landing_inspira_events .row > div{
    width:50%;
  } 
	.landing_inspira_events_item{
		margin-bottom:50px;
	}
	/*Service*/
	.lp_inspira_service_wrapper{
		justify-content:center;
	}
	.lp_inspira_service .lp_inspira_service_wrapper > div{
  	width:33%;
  }
	/*Blog*/
	.landing_inspira_blogs .blogs_photo .bg_item_photo{
		height:300px;
	}
		/*Groups*/
	.landing_inspira_groups_item .groups_photo span{
		height:300px;
	}
	
}
@media (max-width:767px){
/*Common Layout*/
  body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container{
    padding:40px 0;
  }
	body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container .container > p{
		width:100%;
		font-size:15px;
    line-height:26px;
	}
	body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container .container  p br{
		display:none;
	}
	body.inspira_landingpage_1 .layout_main .layout_middle .generic_layout_container > h3, 
	.custom_landing_heading{
		font-size:25px;
		margin-bottom:20px;
	}
	/*Banner*/
	.landing_banner{
		height:400px;
	}
	.landing_banner_content h1{
    font-size:28px;
    line-height:40px;
  }
  .landing_banner_content .btn{
    padding:8px 28px;
    font-size:18px;
  }
  /*Features*/
	.inspira_feature_item_icon i.icon_feature{
		width:32px;
		font-size:32px;
		line-height:32px;
	}
	.inspira_feature_item .inspira_feature_item_icon{
		margin-right:16px;
	}
	[dir="rtl"] .inspira_feature_item .inspira_feature_item_icon{
		margin-left:16px;
		margin-right:0px;
	}
	.inspira_feature_item_cont h3{
		font-size:16px;
	}
	/*Events*/
	.landing_inspira_events .events_photo > a > span{
		width:200px;
    height:200px;
	}
	.landing_inspira_albums{
    margin-top:20px;
   }
	 .landing_inspira_events .title > a{
		font-size:16px;
	 }
	 .landing_inspira_events_item .events_stats p{
    width:40px;
    height:40px;
    border-radius:50%;
    font-size:12px;
  }
	/*Events*/
	/*Albums*/
	.albums_carousel_wrapper .owl-stage-outer .owl-item{
		display:block;
	}
	.albums_carousel_wrapper .owl-item.center .albums_photo img{
    height:230px;
  }
	.landing_inspira_albums_item .info .title a{
		font-size:120%;
	}
	.albums_carousel_wrapper .owl-nav > div{
    width:35px;
    height:35px;
    line-height:35px;
    font-size:20px;
  }
	/*Albums*/
  /*Counter*/
	.generic_layout_container.layout_inspira_landing_page_counter{
    padding:50px 0 !important;
  }
	.landing_inspira_counter_box li{
		padding:15px;
		margin:10px;
	}
	.counter_left{
		padding:0;
	}
	.counter_left > h3{
		font-size:25px;
	}
	.counter_left > p{
		padding:0;
	}
	.landing_inspira_counter_detail{
		font-size:22px;
	}
	.landing_inspira_counter_detail h3{
    font-size:22px;
  }
	.counter_right{
    margin-top:30px;
  }
  /*Counter*/
	/*Vidoes*/
	.landing_inspira_videos .title > a{
		font-size:16px;
	}
	/*Vidoes*/
	/*Music*/
	.landing_inspira_music .title > a{
		font-size:16px;
	}
	.landing_inspira_music .music_photo span{
		height:200px;
	}
	.landing_inspira_music .music_play_icon a{
    width:50px;
    height:50px; 
    font-size:16px;
  }
  /*Music*/
  /*Groups*/
	.landing_inspira_groups_item .groups_photo span{
		height:300px;
	}
	.landing_inspira_groups .info{
		padding:10px;
	}
	.landing_inspira_groups .title > a{
		font-size:120%;
	}
	.landing_inspira_groups_item{
		margin-top:25px;
	}
	/*Groups*/
	/*service*/
	.lp_inspira_service .lp_inspira_service_wrapper > div{
		width:50%;
	}
  .lp_inspira_service_item .title{
		font-size:16px;
	}
 	/*Blog*/
	 .lp_inspira_service_item .des{
			padding:8px 0;
	 }
	 .lp_inspira_service_item .title{
		font-size:16px;
	 }
	 /*App*/
	 .lp_inspira_app_wrapper h3{
		font-size:25px;
	 }
	 .lp_app_right{
    justify-content:flex-start;
    margin-top:15px;
  }
	/*user*/
	.inspira_member_item{
		width:335px;
	}
	.landing_page_member .owl-nav > div{
    width:35px;
    height:35px; 
    font-size:16px;
  }
}
@media (max-width:576px){
  /*events*/
	.landing_inspira_events .row > div{
		width:100%;
	}
		/*service*/
		.lp_inspira_service .lp_inspira_service_wrapper > div{
			width:100%;
		}

		/*user*/
		.inspira_member_item{
			width:335px;
		}
		/*Blog*/
		.lp_inspira_service_icon{
			margin:auto;
		 }
		 .lp_inspira_service_item .des{
				text-align:center
		 }
		 .lp_inspira_service_item .title{
			text-align:center;
		 }
	}
