<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php $allParams = $this->allParams; ?>
<?php if(!empty($allParams['description'])) { ?>
	<p><?php echo $this->translate($allParams['description']); ?></p>
<?php } ?>
<div class="landing_page_container landing_inspira_groups">
  <div class="row justify-content-center ">
    <?php foreach($this->paginator as $item) { ?>
      <div class="col-md-4">
        <div class="landing_inspira_groups_item wow slideInDown">
          <div class="groups_lp_main">
            <div class='groups_photo'>
              <?php echo $this->htmlLink($item->getHref(), $this->itemBackgroundPhoto($item, 'thumb.profile')) ?>
               <div class="info">
               <?php if(!empty($item->category_id)) { ?>
                  <?php $catgory = Engine_Api::_()->getItem('group_category', $item->category_id); ?>
                  <div class="category">
                    <a href="javascript:void(0)"> <?php echo $catgory->title; ?> </a>
                  </div>
                <?php } ?>
                <div class="title">
                  <a href="<?php echo $item->getHref(); ?>"> <?php echo $item->getTitle(); ?> </a>
                </div>
                <div class="member">
                  <a href="javascript:void(0)"><?php echo $this->translate(array('%s member', '%s members', $item->member_count), $this->locale()->toNumber($item->member_count)) ?> </a>
                </div>
             
               </div>
            </div>
          </div>
        </div>
      </div>
    <?php } ?>
  </div>
</div>
