<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

 return array (
  'package' =>
  array (
    'type' => 'theme',
    'name' => 'Inspira',
    'version' => '8.1.0',
    'revision' => '$Revision: 10113 $',
    'path' => 'application/themes/inspira',
    'repository' => 'socialengine.com',
    'title' => 'Inspira',
    'thumb' => 'theme.jpg',
    'author' => '<a href="https://socialengine.com/" style="text-decoration:underline;" target="_blank">SocialEngine</a>',
    'sku' => 'inspira',
    'actions' =>
    array (
      0 => 'install',
      1 => 'upgrade',
      2 => 'refresh',
    ),
    'callback' =>
    array (
      'class' => 'Engine_Package_Installer_Theme',
    ),
    'directories' =>
    array (
      0 => 'application/themes/inspira',
    ),
    'description' => 'inspira',
  ),
  'includefiles' =>
    array (
      'inspira-custom.css',
      'responsive.css',
      'theme.css',
      'variables.css',
      'theme-variables.css',
    ),
  'files' =>
    array (
      'inspira-custom.css',
      'variables.css',
      'theme.css',
    ),
); ?>
