<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class="inspira_styling_buttons">
  <?php echo $this->htmlLink(array('route' => 'admin_default', 'module' => 'inspira', 'controller' => 'settings', 'action' => 'add'), $this->translate("Add New Custom Theme"), array('class' => 'smoothbox inspira_button add_new_theme fa fa-plus', 'id' => 'custom_themes')); ?>
  <?php echo $this->htmlLink(array('route' => 'admin_default', 'module' => 'inspira', 'controller' => 'settings', 'action' => 'add', 'customtheme_id' => $this->customtheme_id), $this->translate("Edit Custom Theme Name"), array('class' => 'smoothbox inspira_button fa fa-pencil', 'id' => 'edit_custom_themes')); ?>
  <?php echo $this->htmlLink(array('route' => 'admin_default', 'module' => 'inspira', 'controller' => 'settings', 'action' => 'delete', 'customtheme_id' => $this->customtheme_id), $this->translate("Delete Custom Theme"), array('class' => 'smoothbox inspira_button fa fa-close', 'id' => 'delete_custom_themes')); ?>
  <a href="javascript:void(0);" data-bs-toggle="tooltip" data-bs-placement="bottom" title="" data-bs-original-title="<?php echo $this->translate('You can not delete this theme, until its deactivated.'); ?>" class="inspira_button fa fa-close disabled" id="deletedisabled_custom_themes" style="display: none;"><?php echo $this->translate("Delete Custom Theme"); ?></a>
</div>
