<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php $allParams = $this->allParams; ?>
<?php if(!empty($allParams['description'])) { ?>
	<p><?php echo $this->translate($allParams['description']); ?></p>
<?php } ?>
<div class="landing_page_container landing_inspira_music">
  <div class="row justify-content-center ">
    <?php foreach($this->paginator as $item) { ?>
      <div class="col-md-4">
        <div class="landing_inspira_music_item wow zoomIn">
          <div class="music_lp_main">
            <div class='music_photo'>
              <?php echo $this->htmlLink($item->getHref(), $this->itemBackgroundPhoto($item, 'thumb.user')) ?>
              <div class="music_play_icon">
                <a href="<?php echo $item->getHref(); ?>"><i class="fas fa-play"></i></a>
              </div>
            </div>
            <div class="info">
              <div class="title">
                <a href="<?php echo $item->getHref(); ?>"> <?php echo $item->getTitle(); ?> </a>
              </div>
              <div class="user">
                <a href="<?php echo $item->getOwner()->getHref(); ?>"><?php echo $item->getOwner()->getTitle(); ?></a>
              </div>
            </div>
          </div>
        </div>
      </div>
    <?php } ?>
  </div>
</div>
