<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class="landing_page_member">
  <div class="member_lp_carousel owl-carousel">
    <?php foreach( $this->paginator as $item ): ?>
      <div class="inspira_member_item">
        <div class="inspira_member_box">
        <?php echo $this->htmlLink($item->getHref(), $this->itemBackgroundPhoto($item, 'thumb.profile', $item->getTitle()), array('class' => 'popularmembers_thumb')) ?>
          <div class='info'>
            <div class='name'> <?php echo $this->htmlLink($item->getHref(), $item->getTitle()) ?> </div>
            <div class='friends'> <?php echo $this->translate(array('%s friend', '%s friends', $item->member_count),$this->locale()->toNumber($item->member_count)) ?> </div>
          </div>
        </div>
      </div>
    <?php endforeach; ?>
  </div>      
</div>

<script type="text/javascript">

owlJqueryObject(".member_lp_carousel").owlCarousel({
  loop:false,
  responsiveClass:true,
  nav:true,
  dots:false,
  autoWidth:true,
  <?php $orientation = ($this->layout()->orientation == 'right-to-left' ? 'rtl' : 'ltr');
    if($orientation == 'rtl') { ?>
  rtl:true,
<?php  }?>
  responsive:{
      0:{
        autoWidth:true,
      },
      600:{
        autoWidth:true,
      },
      1000:{
        autoWidth:true,
      }
  }
});
owlJqueryObject(".owl-prev").html('<i class="fa fa-angle-left"></i>');
owlJqueryObject(".owl-next").html('<i class="fa fa-angle-right"></i>');
</script>
