INSERT IGNORE INTO `engine4_inspira_customthemes` (`name`, `value`, `column_key`, `theme_id`, `default`) VALUES
("Theme - 1", "#F2F2F2", "inspira_box_background_alt_color", 1, 0),
("Theme - 1", "#168AB5", "inspira_button_border_color_hover", 1, 0),
("Theme - 1", "#f2f2f2", "inspira_secondary_button_background_color", 1, 0),
("Theme - 1", "#e5e5e5", "inspira_secondary_button_background_color_hover", 1, 0),
("Theme - 1", "#212529", "inspira_secondary_button_font_color", 1, 0),
("Theme - 1", "#212529", "inspira_secondary_button_font_color_hover", 1, 0),
("Theme - 1", "#E4E6EB", "inspira_secondary_button_border_color", 1, 0),
("Theme - 1", "#d8dadf", "inspira_secondary_button_border_color_hover", 1, 0),
("Theme - 2", "#F2F2F2", "inspira_box_background_alt_color", 2, 0),
("Theme - 2", "#ED6321", "inspira_button_border_color_hover", 2, 0),
("Theme - 2", "#f2f2f2", "inspira_secondary_button_background_color", 2, 0),
("Theme - 2", "#e5e5e5", "inspira_secondary_button_background_color_hover", 2, 0),
("Theme - 2", "#212529", "inspira_secondary_button_font_color", 2, 0),
("Theme - 2", "#212529", "inspira_secondary_button_font_color_hover", 2, 0),
("Theme - 2", "#E4E6EB", "inspira_secondary_button_border_color", 2, 0),
("Theme - 2", "#d8dadf", "inspira_secondary_button_border_color_hover", 2, 0),
("Theme - 3", "#3E3E3E", "inspira_box_background_alt_color", 3, 0),
("Theme - 3", "#168AB5", "inspira_button_border_color_hover", 3, 0),
("Theme - 3", "#343536", "inspira_secondary_button_background_color", 3, 0),
("Theme - 3", "#4c4d4e", "inspira_secondary_button_background_color_hover", 3, 0),
("Theme - 3", "#e4e6eb", "inspira_secondary_button_font_color", 3, 0),
("Theme - 3", "#dbdbdb", "inspira_secondary_button_font_color_hover", 3, 0),
("Theme - 3", "#d8dadf", "inspira_secondary_button_border_color", 3, 0),
("Theme - 3", "#FDFDFD", "inspira_secondary_button_border_color_hover", 3, 0);