<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Inspira_Widget_FooterController extends Engine_Content_Widget_Abstract {

  public function indexAction() {
  
    $this->view->quickLinksMenu = Engine_Api::_()->getApi('menus', 'core')->getNavigation('inspira_quicklinks_footer');
    
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('core_footer');

    //Languages
    $this->view->languageNameList = Engine_Api::_()->getApi('languages', 'core')->getLanguages();
    
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer->getIdentity();

    // Social Links
    $this->view->socialnavigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('core_social_sites');
      
  }

  public function getCacheKey()
  {
      //return true;
  }

  public function setLanguage()
  {
  }
}
