<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
 
<div class="globle_form_popup">
  <?php echo $this->form->setAttrib('class', 'global_form_popup')->render($this) ?>
</div>
