/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Inspira
 * @copyright  Copyright 2006-2022 Webligo Developments
 * @license    http://www.socialengine.com/license/
 * @version    $Id: my.sql 2022-07-14
 */

INSERT IGNORE INTO `engine4_core_modules` (`name`, `title`, `description`, `version`, `enabled`, `type`) VALUES  ('inspira', 'Inspira', 'Inspira Theme Module', '4.0.0', 1, 'extra') ;

INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES
("core_admin_main_inspira", "inspira", "Inspira Theme", "", '{"route":"admin_default","module":"inspira","controller":"settings"}', "core_admin_main", "", 999),
("inspira_admin_main_settings", "inspira", "Global Settings", "", '{"route":"admin_default","module":"inspira","controller":"settings"}', "inspira_admin_main", "", 1),
("inspira_admin_main_footer", "inspira", "Footer Settings", "", '{"route":"admin_default","module":"inspira","controller":"settings", "action":"footer"}', "inspira_admin_main", "", 2),
("inspira_admin_main_styling", "inspira", "Color Schemes", "", '{"route":"admin_default","module":"inspira","controller":"settings", "action":"styling"}', "inspira_admin_main", "", 3),
("inspira_admin_main_managefonts", "inspira", "Manage Fonts", "", '{"route":"admin_default","module":"inspira","controller":"settings", "action":"manage-fonts"}', "inspira_admin_main", "", 4),
("inspira_admin_main_customcss", "inspira", "Custom CSS", "", '{"route":"admin_default","module":"inspira","controller":"custom-theme", "action":"index"}', "inspira_admin_main", "", 5);

INSERT IGNORE INTO `engine4_core_menus` (`name`, `type`, `title`, `order`) VALUES    ("inspira_quicklinks_footer", "standard", "Inspira Theme - Footer Quicklinks", 1);

DROP TABLE IF EXISTS `engine4_inspira_customthemes`;
CREATE TABLE IF NOT EXISTS `engine4_inspira_customthemes` (
  `customtheme_id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(128) NOT NULL,
  `value` varchar(32) NOT NULL,
  `column_key` varchar(128) NOT NULL,
  `theme_id` int(11) NOT NULL,
  `default` TINYINT(1) NOT NULL DEFAULT "0",
  PRIMARY KEY (`customtheme_id`),
  UNIQUE KEY `UNIQUEKEY` (`column_key`,`theme_id`,`default`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1;


INSERT IGNORE INTO `engine4_inspira_customthemes` (`name`, `value`, `column_key`, `theme_id`, `default`) VALUES
("Theme - 1", "1", "theme_color", 1, 0),
("Theme - 1", "1", "custom_theme_color", 1, 0),
("Theme - 1", "#1790BD", "inspira_header_background_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_header_logo_color", 1, 0),
("Theme - 1", "#1790BD", "inspira_mainmenu_background_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_mainmenu_links_color", 1, 0),
("Theme - 1", "#1790BD", "inspira_mainmenu_links_hover_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_mainmenu_links_hover_background_color", 1, 0),
("Theme - 1", "#1790BD", "inspira_minimenu_links_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_minimenu_links_background_color", 1, 0),
("Theme - 1", "#000000", "inspira_footer_background_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_footer_font_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_footer_links_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_footer_border_color", 1, 0),
("Theme - 1", "#1790BD", "inspira_theme_color", 1, 0),
("Theme - 1", "#F5F5F5 ", "inspira_body_background_color", 1, 0),
("Theme - 1", "#5A5A5A", "inspira_font_color", 1, 0),
("Theme - 1", "#5A6064", "inspira_font_color_light", 1, 0),
("Theme - 1", "#1790BD", "inspira_links_color", 1, 0),
("Theme - 1", "#168AB5", "inspira_links_hover_color", 1, 0),
("Theme - 1", "#323232", "inspira_headline_color", 1, 0),
("Theme - 1", "#EAEAEA", "inspira_border_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_box_background_color", 1, 0),
("Theme - 1", "#F2F2F2", "inspira_box_background_alt_color", 1, 0),
("Theme - 1", "#323232", "inspira_form_label_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_input_background_color", 1, 0),
("Theme - 1", "#111111", "inspira_input_font_color", 1, 0),
("Theme - 1", "#D4D4D4", "inspira_input_border_color", 1, 0),
("Theme - 1", "#1790BD", "inspira_button_background_color", 1, 0),
("Theme - 1", "#168AB5", "inspira_button_background_color_hover", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_button_font_color", 1, 0),
("Theme - 1", "#FFFFFF", "inspira_button_font_color_hover", 1, 0),
("Theme - 1", "#1790BD", "inspira_button_border_color", 1, 0),
("Theme - 1", "#168AB5", "inspira_button_border_color_hover", 1, 0),
("Theme - 1", "#f2f2f2", "inspira_secondary_button_background_color", 1, 0),
("Theme - 1", "#e5e5e5", "inspira_secondary_button_background_color_hover", 1, 0),
("Theme - 1", "#212529", "inspira_secondary_button_font_color", 1, 0),
("Theme - 1", "#212529", "inspira_secondary_button_font_color_hover", 1, 0),
("Theme - 1", "#E4E6EB", "inspira_secondary_button_border_color", 1, 0),
("Theme - 1", "#d8dadf", "inspira_secondary_button_border_color_hover", 1, 0),
("Theme - 1", "#F7F7F7", "inspira_comments_background_color", 1, 0),
("Theme - 2", "2", "theme_color", 2, 0),
("Theme - 2", "2", "custom_theme_color", 2, 0),
("Theme - 2", "#F16522", "inspira_header_background_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_header_logo_color", 2, 0),
("Theme - 2", "#F16522", "inspira_mainmenu_background_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_mainmenu_links_color", 2, 0),
("Theme - 2", "#F16522", "inspira_mainmenu_links_hover_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_mainmenu_links_hover_background_color", 2, 0),
("Theme - 2", "#F16522", "inspira_minimenu_links_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_minimenu_links_background_color", 2, 0),
("Theme - 2", "#000000", "inspira_footer_background_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_footer_font_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_footer_links_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_footer_border_color", 2, 0),
("Theme - 2", "#F16522", "inspira_theme_color", 2, 0),
("Theme - 2", "#F5F5F5  ", "inspira_body_background_color", 2, 0),
("Theme - 2", "#5A5A5A", "inspira_font_color", 2, 0),
("Theme - 2", "#5A6064", "inspira_font_color_light", 2, 0),
("Theme - 2", "#F16522", "inspira_links_color", 2, 0),
("Theme - 2", "#ED6321", "inspira_links_hover_color", 2, 0),
("Theme - 2", "#323232", "inspira_headline_color", 2, 0),
("Theme - 2", "#EAEAEA", "inspira_border_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_box_background_color", 2, 0),
("Theme - 2", "#F2F2F2", "inspira_box_background_alt_color", 2, 0),
("Theme - 2", "#323232", "inspira_form_label_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_input_background_color", 2, 0),
("Theme - 2", "#111111", "inspira_input_font_color", 2, 0),
("Theme - 2", "#D4D4D4", "inspira_input_border_color", 2, 0),
("Theme - 2", "#F16522", "inspira_button_background_color", 2, 0),
("Theme - 2", "#ED6321", "inspira_button_background_color_hover", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_button_font_color", 2, 0),
("Theme - 2", "#FFFFFF", "inspira_button_font_color_hover", 2, 0),
("Theme - 2", "#F16522", "inspira_button_border_color", 2, 0),
("Theme - 2", "#ED6321", "inspira_button_border_color_hover", 2, 0),
("Theme - 2", "#f2f2f2", "inspira_secondary_button_background_color", 2, 0),
("Theme - 2", "#e5e5e5", "inspira_secondary_button_background_color_hover", 2, 0),
("Theme - 2", "#212529", "inspira_secondary_button_font_color", 2, 0),
("Theme - 2", "#212529", "inspira_secondary_button_font_color_hover", 2, 0),
("Theme - 2", "#E4E6EB", "inspira_secondary_button_border_color", 2, 0),
("Theme - 2", "#d8dadf", "inspira_secondary_button_border_color_hover", 2, 0),
("Theme - 2", "#F7F7F7", "inspira_comments_background_color", 2, 0),
("Theme - 3", "3", "theme_color", 3, 0),
("Theme - 3", "3", "custom_theme_color", 3, 0),
("Theme - 3", "#1790BD", "inspira_header_background_color", 3, 0),
("Theme - 3", "#FFFFFF", "inspira_header_logo_color", 3, 0),
("Theme - 3", "#1790BD", "inspira_mainmenu_background_color", 3, 0),
("Theme - 3", "#FFFFFF", "inspira_mainmenu_links_color", 3, 0),
("Theme - 3", "#1790BD", "inspira_mainmenu_links_hover_color", 3, 0),
("Theme - 3", "#FFFFFF", "inspira_mainmenu_links_hover_background_color", 3, 0),
("Theme - 3", "#1790BD", "inspira_minimenu_links_color", 3, 0),
("Theme - 3", "#FFFFFF", "inspira_minimenu_links_background_color", 3, 0),
("Theme - 3", "#000000", "inspira_footer_background_color", 3, 0),
("Theme - 3", "#FFFFFF", "inspira_footer_font_color", 3, 0),
("Theme - 3", "#FFFFFF", "inspira_footer_links_color", 3, 0),
("Theme - 3", "#151515", "inspira_footer_border_color", 3, 0),
("Theme - 3", "#1790BD", "inspira_theme_color", 3, 0),
("Theme - 3", "#131313", "inspira_body_background_color", 3, 0),
("Theme - 3", "#E8E8E8", "inspira_font_color", 3, 0),
("Theme - 3", "#CCCCCC", "inspira_font_color_light", 3, 0),
("Theme - 3", "#1790BD", "inspira_links_color", 3, 0),
("Theme - 3", "#168AB5", "inspira_links_hover_color", 3, 0),
("Theme - 3", "#FFFFFF", "inspira_headline_color", 3, 0),
("Theme - 3", "#323131", "inspira_border_color", 3, 0),
("Theme - 3", "#212121", "inspira_box_background_color", 3, 0),
("Theme - 3", "#3E3E3E", "inspira_box_background_alt_color", 3, 0),
("Theme - 3", "#DDDDDD", "inspira_form_label_color", 3, 0),
("Theme - 3", "#212121", "inspira_input_background_color", 3, 0),
("Theme - 3", "#DDDDDD", "inspira_input_font_color", 3, 0),
("Theme - 3", "#383838", "inspira_input_border_color", 3, 0),
("Theme - 3", "#1790BD", "inspira_button_background_color", 3, 0),
("Theme - 3", "#168AB5", "inspira_button_background_color_hover", 3, 0),
("Theme - 3", "#E8E8E8", "inspira_button_font_color", 3, 0),
("Theme - 3", "#FFFFFF", "inspira_button_font_color_hover", 3, 0),
("Theme - 3", "#1790BD", "inspira_button_border_color", 3, 0),
("Theme - 3", "#168AB5", "inspira_button_border_color_hover", 3, 0),
("Theme - 3", "#343536", "inspira_secondary_button_background_color", 3, 0),
("Theme - 3", "#4c4d4e", "inspira_secondary_button_background_color_hover", 3, 0),
("Theme - 3", "#e4e6eb", "inspira_secondary_button_font_color", 3, 0),
("Theme - 3", "#dbdbdb", "inspira_secondary_button_font_color_hover", 3, 0),
("Theme - 3", "#d8dadf", "inspira_secondary_button_border_color", 3, 0),
("Theme - 3", "#FDFDFD", "inspira_secondary_button_border_color_hover", 3, 0),
("Theme - 3", "#3E3E3E", "inspira_comments_background_color", 3, 0);

INSERT IGNORE INTO `engine4_core_settings` (`name`, `value`) VALUES
('inspira.body.fontfamily', 'Georgia, serif'),
('inspira.googlebody.fontfamily', '\"Roboto\"'),
('inspira.googlefonts', '1'),
('inspira.googleheading.fontfamily', '\"Roboto\"'),
('inspira.googlemainmenu.fontfamily', '\"Roboto\"'),
('inspira.googletab.fontfamily', '\"Roboto\"'),
('inspira.headerloggedinoptions', 'a:4:{i:0;s:6:\"search\";i:1;s:8:\"miniMenu\";i:2;s:8:\"mainMenu\";i:3;s:4:\"logo\";}'),
('inspira.headernonloggedinoptions', 'a:4:{i:0;s:6:\"search\";i:1;s:8:\"miniMenu\";i:2;s:8:\"mainMenu\";i:3;s:4:\"logo\";}'),
('inspira.heading.fontfamily', 'Georgia, serif'),
('inspira.helpenable', '1'),
('inspira.leftcolhdingdes', 'Inspire creativity, community, and awareness! SocialEngine PHP - the best choice for community social networking software.'),
('inspira.leftcolhdingemail', 'info@abc.com'),
('inspira.leftcolhdinglocation', 'Los Angeles, USA'),
('inspira.leftcolhdingphone', '+91-1234567890'),
('inspira.mainmenu.fontfamily', 'Georgia, serif'),
('inspira.quicklinksenable', '1'),
('inspira.rightcolhdingdes', 'We are a secure community with 5000+ active members who help you with your queries, post new updates and grow your network.'),
('inspira.rightcolhdingtext', 'WHY JOIN US?'),
('inspira.tab.fontfamily', 'Georgia, serif');

UPDATE `engine4_core_menuitems` SET `params` = '{"icon":"far fa-bell"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_update";
UPDATE `engine4_core_menuitems` SET `params` = '' WHERE `engine4_core_menuitems`.`name` = "core_mini_profile";
UPDATE `engine4_core_menuitems` SET `params` = '{"icon":"fa-sign-in-alt"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_auth";
UPDATE `engine4_core_menuitems` SET `params` = '{"icon":"fa-user-plus"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_signup";
UPDATE `engine4_core_menuitems` SET `params` = '{"icon":"far fa-envelope"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_messages";