
@media (max-width:1400px) and (min-width:1360px){
 .inspira_main_menu_container,
 #global_content{
   width:1200px;
 }
}
@media (max-width:1299px){
  /*Global Css*/
  .layout_user_home_photo>div>img,
  .layout_user_profile_photo div#profile_photo img{
    width:90px;
    height:90px;
  }
  ul.generic_list_widget>li .newestmembers_thumb,
  ul.generic_list_widget>li .popularmembers_thumb{
    width:40px !important;
    height:40px !important;
  }
  ul.generic_list_widget img.thumb_icon.item_photo_user,
  .layout_user_list_online img.thumb_icon.item_photo_user,
  .home-links-user img.thumb_icon,
  .feed_item_photo img.thumb_icon{
    width:40px;
    height:40px;
  }
  .layout_user_home_photo>div>a>img,
  .layout_user_profile_photo div#profile_photo img{
    width:100px;
    height:100px;
  }
  .layout_user_home_photo > div > a > span,
  .layout_user_profile_photo div#profile_photo{
    width: 140px;
    height: 140px;
  }

}
@media (max-width:1199px){
  /**Global Css*/
  .stpage_cont_body{
    width:100%;
  }
  .layout_right,
  .layout_left{
    width:200px;
  }
  .inspira_main_menu_container{
    width:100%;
    padding:0 20px;
  }
  .layout_page_header .generic_layout_container.layout_main{
    padding:0;
  }
  body#global_page_core-index-index div#global_content{
    padding:0 !important;
  }
  .inspira_header .layout_core_search_mini.active #global_search_field {
    width:220px;
  }
  .container {
    width:100% !important;
    max-width:100% !important;
  }  
  body#global_page_user-profile-index .profile_cover_photo_tabs .tabs_alt.tab_collapsed{
    width: 96%;
  }
  .inspira_header_container,
  .inspira_header_horizontal .inspira_main_menu_container{
    width: 100%;
    padding: 0 15px;
  }
  .inspira_header_horizontal .inspira_main_menu .navigation_horizontal > li a{
    padding: 10px 23px;
  }
  
}
@media (min-width:991px) and (max-width:1199px){
  /*Global Page*/
  .browsemembers_criteria li.browse-range-wrapper select{
    width:40%;
  }
  div#browsemembers_results .col-lg-3{
    flex:0 0 auto;
    width:33.33%;
  }
  .browsemembers_results > ul > li{
    min-width:30%;
    max-width:30%;
  }
 /*Common Pulgin Css*/
 ul.grid_wrapper > li,
 ul.blogs_browse > li,
 ul.classifieds_browse > li,
 ul.polls_browse > li,
 ul.groups_browse.grid_wrapper > li{
   margin:0 8px 20px 8px !important;
 }
 /*Events Page*/
 ul.grid_wrapper.events_browse > li{
   min-width:45%;
   max-width:45%;
 } 
}

@media (max-width:1024px){
  /*Header*/
  .inspira_header div#core_menu_mini_menu > ul > li{
    padding-left:10px;
  }
  [dir="rtl"] .inspira_header div#core_menu_mini_menu > ul > li{
    padding-left:0px;
    padding-right:10px;
  }
  .profile_cover_photo img{
    top:0 !important;
  }
  .tabs_alt>ul>li{
    margin-bottom:0px;
  }
  body#global_page_user-profile-index .profile_cover_photo_tabs .tabs_alt > ul > li{
    margin-bottom:0px;
  }
  .profile_cover_photo_tabs .tabs_alt > ul > li{
    margin-bottom:10px;
  }
  .more_tab>a{
    display:block !important;
  }
  .generic_layout_container>h3{
    font-size:17px;
  }
  .inspira_header .layout_core_menu_logo a {
    padding-left:0;
  }
  [dir="rtl"] .inspira_header .layout_core_menu_logo a{
    padding-right:0;
  }
  .inspira_header.lp_header .inspira_main_menu .navigation_horizontal > li a{
    font-size: 15px;
  }
}

@media (min-width:768px) and (max-width:1024px){
  /*Global Page*/
  .layout_right,
  .layout_left{
    float:left;
    clear:both;
  }
  [dir="rtl"] .layout_right,
  [dir="rtl"] .layout_left{
    float:right;
    clear:both;
    padding:0px 0 10px 15px;
  }
  .layout_right{
    padding-left:0;
    padding:0px 30px 0px 0px;
    margin-right:5px;
    margin-left:0;
    padding-left:0;
    padding-right:20px;
  }
  [dir="rtl"] .layout_right{
    padding-left:30px;
    padding:0px 0px 0px 30px;
    margin-right:0px;
    margin-left:5px;
  }
  /*Header*/
  .inspira_header div#core_menu_mini_menu > ul > li{
    padding-left:6px;
  }
  [dir="rtl"] .inspira_header div#core_menu_mini_menu > ul > li{
    padding-left:0;
    padding-right:6px
  }
}
@media (min-width:992px){
   /*header*/
  .inspira_main_menu .navigation > li:hover > .main_menu_submenu{
    display:block !important;
  }
}

@media (min-width:768px){
  /*Tabs*/
  .profile_cover_photo_tabs{
    margin-top:55px;
  }
  .tabs_alt > ul > li{
    display:inline-block;
    padding:0px;
  }
}
@media (min-width:768px) and (max-width:991px){
  /*Global Page*/
  .layout_left>.generic_layout_container,
  .layout_right>.generic_layout_container{
    padding:10px;
  }
  .global_left_panel .layout_core_menu_mini{
    padding-right:0 !important;
  }
  .browsemembers_criteria li.browse-range-wrapper select{
    width:43%;
    margin:0 3px;
  }
 /*Common Pulgin Css */
 ul.grid_wrapper > li,
 ul.blogs_browse > li,
 ul.groups_browse.grid_wrapper > li{
   min-width:46% !important;
   max-width:46% !important;
 }
 .generic_layout_container.layout_core_container_tabs.profile_cover_photo_tabs .tabs_alt > ul > li > a{
  padding: 20px 17px;
 }
}
@media (max-width:991px){
  /*Header*/
  .inspira_header .layout_core_search_mini.active #global_search_field{
    width:250px;
  }
  .inspira_header .layout_core_menu_logo a{
    font-size:20px;
  }
  .inspira_header div#core_menu_mini_menu ul li i:before{
    font-size:18px !important;
  }
  .inspira_header .layout_core_menu_logo a img{
    height:35px;
  }
  /*Global Page*/
  .quicklinks li a,
  ul.blog_categories.category_options.generic_list_widget a,
  #filter_form label{
    font-size:15px;
  }
  ul.polls_browse>li{
    min-width:47%;
    max-width:47%;
    width:100%;
    margin:0 10px 15px 0px;
  }
  /*Member Page*/
  .browsemembers_results > ul > li{
    min-width:46%;
    max-width:46%;
  }
    /*Login Page */
  /*Header Horizontal*/
  .inspira_header_horizontal .header_left_panel,
  .inspira_header_horizontal .navigation_button{
    display: block;
  }
  .inspira_header_horizontal .navigation_horizontal{
    display: none !important;
  }
  /*Landing Page Header*/
  #global_page_core-index-index .layout_inspira_header{
    display: block;
  }
  #global_page_core-index-index .layout_inspira_landing_page_header{
    display: none;
  }
  .inspira_header .header_menu_mini{
    flex: 1;
    padding-left: 15px;
  }
  [dir="rtl"] .inspira_header .header_menu_mini{
    padding-left:0;
    padding-right:15px;
  }
  .header_search{
    display: none;
  }
  .header_search.active {
    display: block;
    position: absolute;
    left: 0;
    right: 0;
    top: 59px;
    max-width: 98%;
    z-index: 9;
  }
  .search_button{
    display: block;
  }
  #global_page_core-index-index .inspira_header .search_button a {
    color:var(--theme-header-minimenu-link-color) !important;
    background:var(--theme-header-minimenu-link-background-color);
    border-color:var(--theme-header-minimenu-link-background-color);
  }
  #global_page_core-index-index .inspira_header .search_button a i{
    color:var(--theme-header-minimenu-link-color) !important;
  }
  #global_page_core-index-index .header_search.active{
    display: block;
  }  
  form.global_form {
    width: 80%;
  }
}
@media (max-width:767px){
  div#global_content{
    padding:0 10px;
  }
  .layout_left,
  .layout_right{
    width:100%;
    float:left;
    padding-left:0;
    padding-right:0;
    margin-left:0;
    margin-right:0;
    float:none;
  }
  .layout_middle{
    padding:0;
    flex:inherit !important;
    width:100%;
  }

  /*Header*/
  .inspira_header_container{
    padding:0;
  }
  .layout_page_header .generic_layout_container.layout_main{
    padding:0 !important;
  }
  .inspira_header .header_logo{
    width:auto;
  }
  .generic_layout_container.layout_core_menu_logo{
    display:flex;
    justify-content:center;
    height:40px;
    align-items:center;
    max-width:65%;
    margin:auto;
  }
  .inspira_header .header-top{
    padding: 8px 0;
    display:block;
    text-align:center;
  }
  .inspira_header .header_menu_mini{
    padding:12px 10px 0;
    margin-top:5px;
    position:inherit;
    justify-content:center;
  }
  .generic_layout_container.layout_core_menu_mini{
    padding:0;
    width:100%;
    display:block;
  }
  .inspira_header_horizontal .inspira_main_menu{
    margin-top:0;
  }
  .layout_core_menu_mini #core_menu_mini_menu > ul{
    display:flex;
    width:100%;
    flex-wrap:wrap;
    justify-content:center;
    align-items:center;
  }
  .inspira_header div#core_menu_mini_menu > ul > li{
    margin:0 0 10px;
    padding-left:4px;
  }
  .inspira_landingpage .inspira_header div#core_menu_mini_menu > ul > li{
    margin-bottom: 0px;
  }
  [dir="rtl"] .inspira_header div#core_menu_mini_menu > ul > li{
    padding-left:0;
    padding-right:4px;
  }
  .inspira_header .layout_core_menu_mini #core_menu_mini_menu > ul > li .core_mini_auth.show_icons{
    font-size:14px !important;
  }
  .inspira_header .layout_core_menu_mini #core_menu_mini_menu > ul > li .core_mini_auth.show_icons,
  .inspira_header .layout_core_menu_mini #core_menu_mini_menu > ul > li .core_mini_signup.show_icons{
    font-size:14px !important;
  }
  .inspira_header:not(.inspira_header_guest) .layout_core_menu_mini #core_menu_mini_menu > ul > li a.menu_core_mini.core_mini_auth {
    border-radius:50%;
    width:36px !important;
    height:36px !important;
    text-align:center;
    line-height:36px !important;
  }
  .inspira_header:not(.inspira_header_guest) .layout_core_menu_mini #core_menu_mini_menu > ul > li a.menu_core_mini.core_mini_auth span {
    font-size:0;
  }
  .inspira_header .layout_core_menu_mini #core_menu_mini_menu > ul > li a.menu_core_mini.core_mini_auth i,
  .inspira_header .layout_core_menu_mini #core_menu_mini_menu > ul > li a.menu_core_mini.core_mini_signup i{
    line-height:inherit
  }
  [dir="rtl"] .layout_left,
  [dir="rtl"] .layout_right {
    padding:0px 0px 0px 0;
    margin-right:0px;
    margin-left:0;
    float:none;
  }
  .minimenu_update_count_bubble,
  .minimenu_message_count_bubble,
  .minimenu_request_count_bubble{
    font-size:10px;
    top:auto;
  }
  .header_menu_mini .pulldown_contents_wrapper{
    top:115px !important;
    margin-top:0 !important;
  }
  #core_menu_mini_menu .pulldown_contents_wrapper:before,
  #core_menu_mini_menu .core_settings_dropdown:before{
    display:none;
  }
  .core_settings_dropdown{
    right:auto;
  }
  .inspira_header .navigation_button{
    position:absolute;
    left: 10px;
    top:10px;
    padding: 0;
  }
  [dir="rtl"] .inspira_header .navigation_button{
    left:auto;
    right:10px;
  }
  .inspira_header .navigation_button .toggle_button i{
    font-size:20px;
  }
  .search_button{
    position:absolute;
    right:10px;
    top:10px;
    margin-right:0;
  }
   [dir="rtl"] .search_button{
    right:auto;
    left:10px;
  }
  .inspira_header .search_button a{
    border-radius:5px;
  }
  .inspira_header #global_search_field {
    right:0;
    left:0;
    width:100%;
    top:65px;
    margin:0;
  }
  /*Search*/
  .search_inner {
    right: 0;
    left: 0;
    top: 50px;
    width: 100%;
  }
  .search_inner{
    right:0;
  }
  [dir="rtl"] .search_inner{
    left:0;
  }
  body#global_page_core-index-index .inspira_header #global_search_field{
    right:0;
  }
  #core_menu_mini_menu .pulldown_contents_wrapper{
    margin:auto !important;
  }
  [dir="rtl"] .inspira_header #global_search_field{
    left:0;
  }
  [dir="rtl"] .guest-user .inspira_header #global_search_field{
    left:0px;
  }
  /*Footer*/
  .inspira_footer_left {
    padding-right:0;
  }
  [dir="rtl"] .inspira_footer_left {
    padding-left:0px;
  }
  .custom_footer_heading{
    font-size:18px;
    padding:0 0 6px;
  }
  .custom_footer_heading:after {
    width:30px;
    height:3px;
  }
  .footer_link_bottom {
    margin-top:15px;
  }
  .footer_link_bottom a{
    margin-bottom:10px;
    font-size:14px;
  }
  .inspira_footer .col-md-2{
    width:50%;
    max-width:50%;
    margin:30px 0 15px;
  }

  /*Tabs*/
  .layout_core_container_tabs{
    position:relative;
  }
  .global_left_panel.panel-collapsed .layout_core_menu_mini #core_menu_mini_menu>ul>li>a{
    padding-left:0;
    padding-right:0;
  }
  .tab_pulldown_contents_wrapper{
	  right:0;
  }
  [dir="rtl"] .tab_pulldown_contents_wrapper{
	  right:auto;
    left: 0;
  }
  div.tabs > ul, div.tabs_alt > ul{
    padding:0;
  }
  /*Global Form*/
  .global_form{
    width:100%;
  }
  .global_form_box .form-element button{
    font-size:14px;
  }
  .global_form div.form-label{
    text-align:left;
  }
  [dir="rtl"] .global_form div.form-label {
    text-align: right;
  }
  .global_form>div>div>h3+div,
  .global_form>div>div>h3+p+div{
    padding:0;
    margin-top:10px;
  }
  .generic_layout_container.layout_core_content{
    padding:10px;
  }
  .global_form div.form-wrapper{
    margin-bottom:0;
  }
  #event_create_form #starttime-wrapper select,
  #event_create_form #endtime-wrapper select{
    width:85px!important;
    display:inline-block;
    margin-bottom:15px;
  }
  .global_form button[type=submit]{
    font-size:14px;
  }
  .global_form div.form-wrapper label{
    font-size:15px;
  }
  #filter_form .browse-range-wrapper input[type="text"],
  form.filters .browse-range-wrapper input[type="text"]{
    width:100px !important;
  }
  /*Chat*/
  .chat_header{
    flex-wrap:wrap;
  }
  .chat_header .pulldown>a{
    margin-top:10px;
  }
  .chat_users_wrapper{
    width:100%;
    height:auto;
    margin-bottom:15px;
    border:none;
  }
  .chat_users>li{
    padding:12px;
  }
  .browsemembers_criteria li.browse-range-wrapper select{
    display:inline-block;
    width:45% !important;
    margin:0 5px;
  }
  .layout_core_banner>div>section h1{
    width:100%;
    font-size:24px;
  }
  .layout_core_banner>div>section article{
    font-size:16px;
    width:100%;
    margin:10px auto 0 auto;
  }
  .browsemembers_results div.browsemembers_results_links,
  .browsemembers_results div.browsemembers_results_info{
    text-align:center;
  }
  .layout_core_banner{
    padding:10px !important;
  }
  .layout_event_browse_search label,
  .layout_group_browse_search label{
    font-size:15px;
  }
  .layout_event_browse_search .form-element button,
  .layout_group_browse_search .form-element button{
    font-size:14px;
  }
  ul.albums_manage .albums_manage_photo{
    width:100%;
  }
  ul.albums_manage .albums_manage_options{
    float:left;
    width:100%;
  }
  ul.albums_manage .albums_manage_info{
    width:100%;
    margin-top:5px;
  }
  #TB_window{
    width:100% !important;
    right:0;
    left:0 !important;
  }
  .layout_user_home_photo>div>img,
  .layout_user_profile_photo div#profile_photo img{
    width:140px;
    height:140px;
  }
  html .profile_cover_photo_empty:before{
    height:100%;
  }
  ul.profile_friends .profile_friends_lists{
    display:flex;
    flex-wrap:wrap;
  }
  ul#activity-feed .comments{
    width:auto !important;
  }
  ul.profile_friends .profile_friends_lists .pulldown,
  ul.profile_friends .profile_friends_lists .profile_friends_options{
    display:block !important;
    width:100%;
    text-align:center;
    margin-left:0;
    margin-bottom:10px;
  }
  .profile_friends_lists>.pulldown>a,
  ul.profile_friends .profile_friends_options>a{
    display:block;
  }
  form.global_form{
    width:100%;
  }
  #global_page_user-edit-profile .global_form div.form-element{
    min-width: 80%;
    max-width: 80%;
  }
  #global_page_user-edit-profile div.field-privacy-selector ul{
    left:auto;
    right:-10px;
  }
  /*Alubm Page*/
  ul.thumbs.grid_wrapper > li{
    max-width:46% !important;
    margin:8px 10px !important;
  }
  /*cover photo*/
  .profile_cover_wrapper .profile_main_photo .item_photo{
    margin:0 auto;
  }
  .cover_photo_profile_options #profile_status{
    text-align:center;
  }
  html .cover_photo_profile_options .profile_status_text{
    display:none !important;
  }
  .layout_page_user_auth_login {
    width:100%;
    margin:auto;
  }
  body#global_page_user-profile-index .profile_cover_photo_tabs .tabs_alt.tab_collapsed{
    position: relative;
    margin-bottom: 10px !important;
    width: 100% !important;
  }
  /*Member Profile*/
  body#global_page_user-profile-index .profile_cover_photo_tabs .tabs_alt.tab_collapsed{
    margin: 0;
  }
  .profile_cover_photo_tabs {
    margin-top: 0;
  }
  .user_login_page .user_login_form{
    width: 90%;
    margin:0 auto;
  }
  .user_login_page{
    padding: 20px 0;
  }
  #global_page_core-index-index .header_search{
    width: 100%;
  }

}
@media(max-width:767px ) and (min-width:576px){
  /*Common Pulgin Css */
 ul.blogs_browse > li,
 ul.polls_browse > li,
 .grid_wrapper.events_browse > li{
   min-width:48% !important;
   max-width:48% !important;
 }
 ul.classifieds_browse > li,
 ul.groups_browse.grid_wrapper > li,
 ul.videos_browse > li{
  min-width:46% !important;
  max-width:46% !important;
 }
 
}

@media (min-width:600px){
 /*Alubm Page*/
 ul.grid_wrapper > li{
   margin:0 9px 25px 9px;
 }
}

@media(max-width:575px){
  /*Alubm Page*/
 ul.thumbs.grid_wrapper > li{
  max-width:100% !important;
  margin:8px 10px !important;
 }
 /*Poll Page */
 ul.polls_browse > li{
   min-width:100%;
   max-width:100%;
 }
  /*Footer*/
  .footer_copyright_section{
    flex-wrap:wrap;
  }
  .footer_copyright_section > div{
    margin:10px 0;
  }
}
@media (max-width:479px){
  .inspira_header .layout_core_menu_mini #core_menu_mini_menu > ul > li .core_mini_auth.show_icons,
  .inspira_header .layout_core_menu_mini #core_menu_mini_menu > ul > li .core_mini_signup.show_icons{
    border-width:1px;
    padding:0 10px;
    border-radius:5px;
    line-height:32px !important;
    height:36px !important;
  }
  .inspira_header .layout_core_menu_mini #core_menu_mini_menu>ul>li>a.core_mini_profile>.thumb_icon{
    height:30px;
    width:30px;
  }
  div#searchform form select,
  div#searchform form button{
    margin-left:0px;
    margin-top:15px;
  }
  div#searchform form select,
  div#searchform form input{
    width:100% !important;
    max-width:100%;
  }
  div#searchform form{
    flex-direction:column;
  }
   /*Member Page*/
  .browsemembers_results > ul > li{
    min-width:100%;
    max-width:100%;
  }
   /*Event Page */
  form#event_create_form .event_calendar_container{
    display:block !important;
    margin-bottom:15px !important;
  }
}
