<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php $allParams = $this->allParams; ?>
<div class="inspira_features_wrapper clearfix inspira_bxs" id="feautres">
  <?php if(!empty($allParams['description'])) { ?>
    <p class="inspira_text_light"><?php echo $this->translate($allParams['description']); ?></p>
  <?php } ?>
  
<div class="container inspira_features_block">
  <div class="row">
    <div class="col-12 col-md-6 col-lg-4">
      <ul class="inspira_feature_inner">
        <?php for($i=1;$i<=3;$i++) { ?>
          <?php if(!empty($allParams['icon'.$i]) || !empty($allParams['heading'.$i]) || !empty($allParams['description'.$i])) { ?>
            <li class="wow slideInLeft">
              <div class="inspira_feature_item">
                <?php if(!empty($allParams['icon'.$i])) { ?>
                  <div class="inspira_feature_item_icon">
                    <i class="icon_feature <?php echo $allParams['icon'.$i]; ?>"></i>
                  </div>
                <?php } ?>
                <div class="inspira_feature_item_cont">
                  <?php if(!empty($allParams['heading'.$i])) { ?>
                    <h3><?php echo $this->translate($allParams['heading'.$i]); ?></h3>
                  <?php } ?>
                  <?php if(!empty($allParams['description'.$i])) { ?>
                    <p class="inspira_text_light"><?php echo $this->translate($allParams['description'.$i]); ?></p>
                  <?php } ?>
                </div>
              </div>
            </li>
          <?php } ?>
        <?php } ?>
      </ul>
    </div>
    <div class="col-12 col-lg-4 d-none d-lg-block inspira_feature_bg">
      <figure class="wow slideInUp">
        <img src="<?php echo !empty($allParams['rightsideimage']) ? $allParams['rightsideimage'] : 'application/modules/Inspira/externals/images/comunity.jpg'; ?>"  alt="img" />
        <?php if(!empty($allParams['rightsideurl'])) { ?>
          <a href="<?php echo $allParams['rightsideurl']; ?>" class="pulse-button" data-lity=""><i class="fa fa-play"></i></a>
        <?php } ?>
      </figure>
    </div>
    
    <div class="col-12 col-md-6 col-lg-4">
      <ul class="inspira_feature_inner">
        <?php for($i=4;$i<=6;$i++) { ?>
          <?php if(!empty($allParams['icon'.$i]) || !empty($allParams['heading'.$i]) || !empty($allParams['description'.$i])) { ?>
            <li class="wow slideInRight">
              <div class="inspira_feature_item">
                <?php if(!empty($allParams['icon'.$i])) { ?>
                  <div class="inspira_feature_item_icon">
                    <i class="icon_feature <?php echo $allParams['icon'.$i]; ?>"></i>
                  </div>
                <?php } ?>
                <div class="inspira_feature_item_cont">
                  <?php if(!empty($allParams['heading'.$i])) { ?>
                    <h3><?php echo $this->translate($allParams['heading'.$i]); ?></h3>
                  <?php } ?>
                  <?php if(!empty($allParams['description'.$i])) { ?>
                    <p class="inspira_text_light"><?php echo $this->translate($allParams['description'.$i]); ?></p>
                  <?php } ?>
                </div>
              </div>
            </li>
          <?php } ?>
        <?php } ?>
      </ul>
   </div>
  </div>
  </div>
</div>
<script>
  var wow = new WOW ({
    offset:       75,          // distance to the element when triggering the animation (default is 0)
    mobile:       false,       // trigger animations on mobile devices (default is true)
  });
  wow.init();
</script>
