<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php include APPLICATION_PATH .  '/application/modules/Inspira/views/scripts/_adminHeader.tpl';?>

<div class='clear'>
  <div class='settings'>
    <?php echo $this->form->render($this); ?>
  </div>
</div>

<script>
  en4.core.runonce.add(function() {
    usegooglefont('<?php echo Engine_Api::_()->getApi('settings', 'core')->getSetting('inspira.googlefonts', 1);?>');
  });
  
  function usegooglefont(value) {
    if(value == 1) {
      if(document.getElementById('inspira_bodygrp'))
        document.getElementById('inspira_bodygrp').style.display = 'none';
      if(document.getElementById('inspira_headinggrp'))
        document.getElementById('inspira_headinggrp').style.display = 'none';
      if(document.getElementById('inspira_mainmenugrp'))
        document.getElementById('inspira_mainmenugrp').style.display = 'none';
      if(document.getElementById('inspira_tabgrp'))
        document.getElementById('inspira_tabgrp').style.display = 'none';
      if(document.getElementById('inspira_googlebodygrp'))
        document.getElementById('inspira_googlebodygrp').style.display = 'block';
      if(document.getElementById('inspira_googleheadinggrp'))
        document.getElementById('inspira_googleheadinggrp').style.display = 'block';
      if(document.getElementById('inspira_googlemainmenugrp'))
        document.getElementById('inspira_googlemainmenugrp').style.display = 'block';
      if(document.getElementById('inspira_googletabgrp'))
        document.getElementById('inspira_googletabgrp').style.display = 'block';
    } else {
      if(document.getElementById('inspira_bodygrp'))
        document.getElementById('inspira_bodygrp').style.display = 'block';
      if(document.getElementById('inspira_headinggrp'))
        document.getElementById('inspira_headinggrp').style.display = 'block';
      if(document.getElementById('inspira_mainmenugrp'))
        document.getElementById('inspira_mainmenugrp').style.display = 'block';
      if(document.getElementById('inspira_tabgrp'))
        document.getElementById('inspira_tabgrp').style.display = 'block';
      if(document.getElementById('inspira_googlebodygrp'))
        document.getElementById('inspira_googlebodygrp').style.display = 'none';
      if(document.getElementById('inspira_googleheadinggrp'))
        document.getElementById('inspira_googleheadinggrp').style.display = 'none';
      if(document.getElementById('inspira_googlemainmenugrp'))
        document.getElementById('inspira_googlemainmenugrp').style.display = 'none';
      if(document.getElementById('inspira_googletabgrp'))
        document.getElementById('inspira_googletabgrp').style.display = 'none';
    }
  }
</script>
<script type="application/javascript">
  scriptJquery('.core_admin_main_inspira').parent().addClass('active');
</script>
