<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

return array (
  'package' =>
  array (
    'type' => 'module',
    'name' => 'inspira',
    'version' => '8.1.0',
    'path' => 'application/modules/Inspira',
    'title' => 'Inspira',
    'description' => 'Responsive, modern theme with features to delight you and your members!',
    'author' => '<a href="https://socialengine.com/" style="text-decoration:underline;" target="_blank">SocialEngine</a>',
    'thumb' => 'application/modules/Inspira/externals/images/thumb.png',
    'callback' => array(
        'path' => 'application/modules/Inspira/settings/install.php',
        'class' => 'Inspira_Installer',
    ),
    'actions' =>
    array (
      0 => 'install',
      1 => 'upgrade',
      2 => 'refresh',
      3 => 'enable',
      4 => 'disable',
    ),
    'directories' =>
    array(
      'application/modules/Inspira',
      'application/themes/inspira',
			'externals/jQuery/owlcarousel',
    ),
    'files' =>
    array (
			'application/languages/en/inspira.csv',
    ),
  ),
  'items' => array(
    'inspira_customthemes',
  ),
  //Load by default css / js file ---------------------------------------------------------------------
  'loadDefault' => array(
    "js" => array(
      'application/modules/Inspira/externals/scripts/lity.min.js',
      'application/modules/Inspira/externals/scripts/wow.min.js',
    ),
    'css' => array(
      'application/modules/Inspira/externals/styles/lity.min.css',
      'application/modules/Inspira/externals/styles/animate.css',
      'application/themes/inspira/landing-page-1.css',
      'application/themes/inspira/landing-page-2.css'
    )
  ),
  // Hooks ---------------------------------------------------------------------
	'hooks' => array(
		array(
			'event' => 'onRenderLayoutDefault',
			'resource' => 'Inspira_Plugin_Core'
		),
		array(
			'event' => 'onRenderLayoutDefaultSimple',
			'resource' => 'Inspira_Plugin_Core'
		),       
	),
);
