<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php include APPLICATION_PATH .  '/application/modules/Inspira/views/scripts/_adminHeader.tpl';?>

<h2><?php echo $this->translate('Global Settings') ?></h2>
<p><?php echo $this->translate("These settings affect all members in your community.") ?></p>
<?php echo 'More info: <a href="https://community.socialengine.com/blogs/597/124/inspira-theme" target="_blank">See KB article</a>'; ?>
<br />	
<br />
<div class='clear'>
  <div class='settings'>
    <?php echo $this->form->render($this); ?>
  </div>
</div>

<script type="text/javascript">
  en4.core.runonce.add(function() {
    hideShowSettings('<?php echo Engine_Api::_()->getApi('settings', 'core')->getSetting("menuType",'horizontal'); ?>');
  });
  function hideShowSettings(value) {
    if(value == 'horizontal') {
      scriptJquery('#menuCount-wrapper').show();
    } else {
      scriptJquery('#menuCount-wrapper').hide();
    }
  }
  
  function confirmChangeLandingPage(value){
    if((value == 1 || value == 2) && !confirm('Are you sure want to set the default Landing page of this theme as the Landing page of your website. For old landing page you will have to manually make changes in the Landing page from Layout Editor. Backup page of your current landing page will get created with the name "Backup - Landing Page".')) {
      scriptJquery('#inspira_changelanding-0').prop('checked',true);
    } else if(value == 0) {
    } else {
      scriptJquery('#inspira_changelanding-0').removeAttr('checked');
      scriptJquery('#inspira_changelanding-0').prop('checked',false);
    }
  }
</script>
<script type="application/javascript">
  scriptJquery('.core_admin_main_inspira').parent().addClass('active');
</script>
