<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php $allParams = $this->allParams; ?>
<?php if(!empty($allParams['description'])) { ?>
	<p><?php echo $this->translate($allParams['description']); ?></p>
<?php } ?>
<div class="landing_page_container landing_inspira_events">
  <div class="row justify-content-center ">
    <?php foreach($this->paginator as $item) { ?>
      <div class="col-md-3">
        <div class="landing_inspira_events_item wow zoomIn">
          <div class="events_lp_main">
            <div class='events_photo'>
              <?php echo $this->htmlLink($item->getHref(), $this->itemBackgroundPhoto($item, 'thumb.profile')) ?>
                <div class="info">
                <div class="title">
                  <a href="<?php echo $item->getHref(); ?>"><?php echo $item->getTitle(); ?></a>
                </div>
              </div>
							<div class="events_stats">
								<p class="list_comments">
									<i class="fa fa-comments"></i>
									<span><?php echo $item->comment_count; ?></span>
								</p>
								<p class="list_likes">
								<i class="fa fa-thumbs-up"></i>
								<span><?php echo $item->like_count; ?></span>
								</p>
								<p class="list_views">
								<i class="fa fa-eye"></i>
								<span><?php echo $item->view_count; ?></span>
								</p>
							</div>
            </div>
          </div>
        </div>
      </div>
    <?php } ?>
  </div>
</div>
