.inspira_color_schemes_form form > div > div{
	position:relative;
}
.inspira_color_schemes_form #theme_color-label{
	display:none !important;
}
.inspira_color_schemes_form #theme_color-wrapper .form-element{
  max-width:100%;
}
.inspira_color_schemes_form div#theme_color-label{
	float:none;
	display:block;
	text-align:center;
	width:100%;
	margin-bottom:20px;
}
.inspira_color_schemes_form #theme_color-element .form-options-wrapper{
	display:flex;
	flex-wrap:wrap;
	justify-content:center;
	align-items: flex-start;
	width:100%;
}
.inspira_color_schemes_form #theme_color-element .form-options-wrapper li{
	width:30%;
	display:flex;
	margin:0 0 10px !important;
	margin-right:15px !important;
	position:relative;
	border-width:4px;
}
.inspira_color_schemes_form #theme_color-element .form-options-wrapper li img{
	width:100%;
}
.inspira_styling_buttons a{
	border:1px solid var(--theme-button-background-color);
	border-radius:4px;
	padding:12px 10px;
	margin-bottom:10px;
	color:var(--theme-button-background-color);
	font-family:inherit !important;
	margin-right:10px;
	font-weight:400;
}
[dir="rtl"] .inspira_styling_buttons a{
	margin-left:10px;
	margin-right:0px;
}
.inspira_styling_buttons  a#custom_themes{
  display:inline-block !important;
}
.inspira_styling_buttons a:before{
	font-family:'Font Awesome 6 Free';
	margin-right:5px;
	font-weight:600;
}
.inspira_color_schemes_form #theme_color-element .form-options-wrapper li input{
	position:absolute;
	top:0;
	left:0;
	right:0;
	bottom:0;
	width:100%;
	height:100%;
	opacity:0;
	cursor:pointer;
}
.colored-border{
	border:4px solid var(--theme-button-background-color);
}
.inspira_styling_buttons .add_new_theme{
	position:absolute;
	top:0;
	right:0;
}
.inspira_color_schemes_form #header_settings-wrapper, 
.inspira_color_schemes_form #footer_settings-wrapper, 
.inspira_color_schemes_form #body_settings-wrapper{
  border-bottom-width:1px;
}
.inspira_color_schemes_form .form-label, 
.inspira_color_schemes_form .form-label, 
.inspira_color_schemes_form .form-label{
  font-size:14px;
  width:auto !important;
}
.inspira_color_schemes_form #header_settings_group > fieldset > div, 
.inspira_color_schemes_form #footer_settings_group > fieldset > div, 
.inspira_color_schemes_form #body_settings_group > fieldset > div{
	margin-right:3%;
	display:inline-block;
	width:30%;
}
.inspira_color_schemes_form input[type=text]{
	min-width:100% !important;
  margin-top:10px;
	width:100% !important;
}
.inspira_color_schemes_form .form-options-wrapper label .custom_theme_name{
	font-weight:600;
	text-align: center;
	display: block;
	padding: 8px 0;
	font-size: 1rem;
}
.inspira_styling_buttons a.disabled {
	border-color: var(--theme-font-light-color);
	color: var(--theme-font-light-color);
	cursor: inherit;
}