.light_mode{
  --inspira-header-background-color:#1790BD;
  --inspira-header-logo-color:#FFFFFF;
  --inspira-mainmenu-background-color:#1790BD;
  --inspira-mainmenu-links-color:#FFFFFF;
  --inspira-mainmenu-links-hover-color:#1790BD;
  --inspira-mainmenu-links-hover-background-color:#FFFFFF;
  --inspira-minimenu-links-color:#1790BD;
  --inspira-minimenu-links-background-color:#FFFFFF;
  --inspira-footer-background-color:#000000;
  --inspira-footer-font-color:#FFFFFF;
  --inspira-footer-links-color:#FFFFFF;
  --inspira-footer-border-color:#FFFFFF;
  --inspira-body-background-color:#F5F5F5;
  --inspira-font-color:#5A5A5A;
  --inspira-font-color-light:#5A6064;
  --inspira-headline-color:#323232;
  --inspira-border-color:#EAEAEA;
  --inspira-box-background-color:#FFFFFF;
  --inspira-box-background-alt-color:#F2F2F2;
  --inspira-form-label-color:#323232;
  --inspira-input-background-color:#FFFFFF;
  --inspira-input-font-color:#959595;
  --inspira-input-border-color:#D4D4D4;
  --inspira-secondary-button-background-color:#F2F2F2;
  --inspira-secondary-button-background-color-hover:#E5E5E5;
  --inspira-secondary-button-font-color:#212529;
  --inspira-secondary-button-font-color-hover:#212529;
  --inspira-secondary-button-border-color:#E4E6EB;
  --inspira-secondary-button-border-color-hover:#D8DADF;
  --inspira-comments-background-color:#F7F7F7;
}

.dark_mode{
  --inspira-header-background-color:#1790BD;
  --inspira-header-logo-color:#FFFFFF;
  --inspira-mainmenu-background-color:#1790BD;
  --inspira-mainmenu-links-color:#FFFFFF;
  --inspira-mainmenu-links-hover-color:#1790BD;
  --inspira-mainmenu-links-hover-background-color:#FFFFFF;
  --inspira-minimenu-links-color:#1790BD;
  --inspira-minimenu-links-background-color:#FFFFFF;
  --inspira-footer-background-color:#000000;
  --inspira-footer-font-color:#FFFFFF;
  --inspira-footer-links-color:#FFFFFF;
  --inspira-footer-border-color:#151515;
  --inspira-body-background-color:#131313;
  --inspira-font-color:#E8E8E8;
  --inspira-font-color-light:#CCCCCC;
  --inspira-headline-color:#FFFFFF;
  --inspira-border-color:#323131;
  --inspira-box-background-color:#212121;
  --inspira-box-background-alt-color:#3E3E3E;
  --inspira-form-label-color:#DDDDDD;
  --inspira-input-background-color:#212121;
  --inspira-input-font-color:#DDDDDD;
  --inspira-input-border-color:#383838;
  --inspira-secondary-button-background-color:#343536;
  --inspira-secondary-button-background-color-hover:#4C4D4E;
  --inspira-secondary-button-font-color:#E4E6EB;
  --inspira-secondary-button-font-color-hover:#DBDBDB;
  --inspira-secondary-button-border-color:#585a5e;
  --inspira-secondary-button-border-color-hover:#FDFDFD;
  --inspira-comments-background-color:#3E3E3E;
}
/*
DEFAULT STYLES FOR THIS --theme
*/
:root {
  /*
  PAGE WIDTHS & BACKGROUND COLOR
  Specify the top bar wrapper width (which contains the mini menu, logo, and main menu
  by default), the footer width, and the width of left & right-side columns.
  */
  --theme-main-width:1200px;
  --theme-header-width:100%;
  --theme-header-menu-width:var(--theme-main-width);
  --theme-content-width:var(--theme-main-width);
  --theme-content-columns-left-width:300px;
  --theme-content-columns-right-width:300px;
  --theme-body-background-color:var(--inspira-body-background-color);
  --theme-color:var(--inspira-theme-color);
  --theme-base-font-color:#fff;
  /*
  HEADER AND FOOTER COLORS
  These values are only used to style the site-wide header and footer.
  */
  --theme-topbar-logo-color:var(--inspira-header-logo-color);
  --theme-header-background-color:var(--inspira-header-background-color);
  --theme-header-menu-background-color:var(--inspira-mainmenu-background-color);
  --theme-header-menu-link-background-color:var(--inspira-mainmenu-background-color);
  --theme-header-menu-link-background-color-hover:var(--inspira-mainmenu-links-hover-background-color);
  --theme-header-menu-link-color:var(--inspira-mainmenu-links-color);
  --theme-header-menu-link-hover-color:var(--inspira-mainmenu-links-hover-color);
  --theme-header-minimenu-link-color:var(--inspira-minimenu-links-color);
	--theme-header-minimenu-link-background-color:var(--inspira-minimenu-links-background-color);
  --theme-footer-background-color:var(--inspira-footer-background-color);
  --theme-footer-font-color:var(--inspira-footer-font-color);
  --theme-footer-link-color:var(--inspira-footer-links-color);
  --theme-footer-link-hover-color:var(--theme-color);
  --theme-footer-border-color:var(--inspira-footer-border-color);
  /*
  TEXT & LINKS
  These values affect the size and colors of your text and links throughout your layout.
  */
  --theme-font-color:var(--inspira-font-color);
  --theme-font-color-light:var(--inspira-font-color-light);
  --theme-link-color:var(--inspira-links-color);
  --theme-link-color-hover:var(--inspira-links-hover-color);
  --theme-headline-color:var(--inspira-headline-color);
  --theme-border-color:var(--inspira-border-color);
  /*
  INPUT FIELDS AND BUTTONS
  These values style input fields and buttons that appear throughout the layout.
  */
  --theme-input-background-color:var(--inspira-input-background-color);
  --theme-input-font-color:var(--inspira-input-font-color);
  --theme-input-border-colors:var(--inspira-input-border-color);
  --theme-button-background-color:var(--inspira-button-background-color);
  --theme-button-background-color-hover:var(--inspira-button-background-color-hover);
  --theme-button-font-color:var(--inspira-button-font-color);
  --theme-button-font-color-hover:var(--inspira-button-font-color-hover);
  --theme-button-border-color:var(--inspira-button-border-color);
  --theme-button-border-color-hover:var(--inspira-button-border-color-hover);
  --theme-secondary-button-background-color:var(--inspira-secondary-button-background-color);
  --theme-secondary-button-background-color-hover:var(--inspira-secondary-button-background-color-hover);
  --theme-secondary-button-font-color:var(--inspira-secondary-button-font-color);
  --theme-secondary-button-font-color-hover:var(--inspira-secondary-button-font-color-hover);
  --theme-secondary-button-border-color:var(--inspira-secondary-button-border-color);
  --theme-secondary-button-border-color-hover:var(--inspira-secondary-button-border-color-hover);
  /*
  TABS (BUTTON-STYLE)
  These colors are applied to the button-style tab menus which are often shown
  on browse pages.
  */
	--theme-buttontabs-font-color:var(--inspira-font-color);
	--theme-buttontabs-font-color-hover:var(--theme-base-font-color);
	--theme-buttontabs-font-color-active:var(--theme-base-font-color);
  --theme-buttontabs-background-color-hover:var(--inspira-theme-color);
	--theme-buttontabs-border-color:var(--theme-color);
	--theme-buttontabs-border-color-active:var(--inspira-theme-color);
  /*
  TABS
  These colors are applied to tab menus (as seen on several pages, including
  the member profile page).
  */
  --theme-tabs-background-color:var(--inspira-box-background-color);
  --theme-tabs-background-color-hover:var(--theme-button-background-color-hover);
  --theme-tabs-background-color-active:var(--theme-button-background-color-hover);
  --theme-tabs-font-color:var(--inspira-font-color);
  --theme-tabs-font-hover-color:var(--theme-button-font-color-hover);
  --theme-tabs-font-color-active:var(--theme-button-font-color-hover);
  --theme-tabs-border-color:transparent;
  --theme-tabs-border-color-hover:var(--inspira-theme-color);
  --theme-tabs-border-color-active:var(--inspira-theme-color);
  /*
  LISTS
  These colors are applied to some lists, especially in pull-down menus.
  */
  --theme-list-background-color:var(--inspira-box-background-color);
  --theme-list-background-color-alt:var(--inspira-box-background-alt-color);
  --theme-list-background-color-hover:var(--inspira-box-background-alt-color);
  --theme-comments-background-color:var(--inspira-comments-background-colo);
  /*
  TAGS
  These colors are applied to tags, which appear on blogs, messages, etc.
  */
  --theme-tag-background-color:var(--theme-secondary-button-background-color);
  --theme-tag-font-color:var(--theme-secondary-button-font-color);
  /*
  INLINE PULLDOWN MENUS
  These colors style the inline pulldown menus that appear throughout the layout.
  */
  --theme-pulldown-background-color:var(--theme-list-background-color);
  --theme-pulldown-background-color-hover:var(--theme-button-background-color);
	--theme-pulldown-background-color-active:var(--theme-button-background-color);
  --theme-pulldown-font-color-active:var(--theme-button-font-color);
  --theme-pulldown-border-color:var(--theme-border-color);
  --theme-pulldown-contents-background-color:var(--theme-list-background-color);
  --theme-pulldown-contents-list-background-color-hover:var(--theme-list-background-color-hover);
  --theme-pulldown-contents-list-background-color-active:var(--theme-list-background-color-hover);
  --theme-pulldown-contents-list-font-color-active:var(--theme-font-color);
  
  /*Font Size*/
  --theme-font-size:0.875rem;
	--theme-font-size-small:0.8125rem;
  --theme-headline-size-large:1.5rem;
  --theme-headline-size-medium:1.25rem;
  --theme-title-size:var(--theme-font-size);
  --theme-menu-link-size:1.0625rem;
  --theme-tabs-font-size:0.875rem;
  --theme-font-weight-bold:500;

  /*Font Family*/
  --theme-font-family:var(--inspira-body-fontfamily);
	--theme-heading-font-family:var(--inspira-heading-fontfamily);
  --theme-header-menu-font-family:var(--inspira-mainmenu-fontfamily);
	--theme-buttontabs-font-family:var(--inspira-tab-fontfamily);
  --theme-tabs-font-family:var(--inspira-tab-fontfamily);
  
  --theme-item-spacing:0.625rem;
  --theme-item-radius:0.625rem;
  --theme-item-transition:all .2s ease-in-out;
  --theme-item-shadow:0 0 5px rgba(0, 0, 0, .1);
  --theme-item-shadow-hover:0 0 5px rgba(0, 0, 0, .2);
  --theme-widget-spacing:1.25rem;
  --theme-widget-radius:0.3125rem;
}