body.inspira_landingpage_2 #global_header{
  display:none;
}
body.inspira_landingpage_2 #global_wrapper{
  margin-top:0;
  padding:0;
}
body.inspira_landingpage_2 #global_content{
  width:100%;
  max-width:100%;
}
.inspira_landingpage_2 #global_content .layout_middle{
	padding:0;
}
body.inspira_landingpage_2 .generic_layout_container.layout_middle .generic_layout_container:nth-child(2n+2){
  background-color:transparent !important;
}
body.inspira_landingpage_2 #global_footer{
  margin-top:0;
}
.layout_inspira_landing_page_main *{
  box-sizing:border-box;
}
.generic_layout_container.layout_inspira_landing_page_main{
  padding:0;
  margin:0;
  border-width:0;
}
.generic_layout_container.layout_inspira_landing_page_main h3{
  display:none;
}
.banner_landing_main_inner{
  align-items:center;
  display:flex;
  flex-wrap:wrap;
  height:100vh;
}
.banner_main_left{
  width:55%;
  height:100vh;
  position:relative;
  background-repeat:no-repeat;
  background-size:cover !important;
  background-position:center;
  padding:10px 50px;
}
.banner_main_left img{
  max-width:100%;
}
.banner_main_right{
  padding:0 40px;
  width:45%;
  text-align:left;
  position:relative;
  display:flex;
  align-items:center;
  height:100%;
}
.banner_main_right .landing-banner_right_inner{
  max-width:400px;
  padding-top:50px;
  margin:auto;
}
.banner_main_right .layout_core_menu_logo{
  font-size:28px;
  margin:15px 0 30px;
  font-weight:600;
  text-align:center;
}
.banner_main_right .layout_core_menu_logo img{
  max-width:100%;
  max-height:200px;
}
.banner_main_right h2{
  font-size:24px;
  margin-bottom:0;
  line-height:32px;
  font-weight:600;
  margin-bottom:30px;
  text-align:center;
}
[dir="rtl"] .banner_main_right .layout_core_menu_logo,
[dir="rtl"] .banner_main_right h2{
  text-align:center;
}
.banner_main_right .btn_group .btn{
  padding:0 15px;
  height:40px;
  font-size:14px;
  border-radius:50px;
  border:1px solid;
  font-weight:600;
  transition:.5s;
  display:flex;
  align-items:center;
  justify-content:center;
}
.banner_main_right .btn_group .btn.btn-primary{
  background:transparent;
}
.banner_main_right .btn_group a + a{
  margin-top:16px !important;
}
.banner_main_right .btn_group .btn i{
  margin-right:10px;
}
[dir="rtl"] .banner_main_right .btn_group .btn i{
  margin-left:10px;
  margin-right:0;
}
.banner_main_right .btn_group .facebook_btn{
  border-color:#3b5998;
  color:#3b5998;
}
.banner_main_right .btn_group .facebook_btn:hover{
  background-color:#3b5998;
  color:#fff;
}
.banner_main_right .btn_group .twitter_btn{
  border-color:#1aa0ef;
  color:#1aa0ef;
}
.banner_main_right .btn_group .twitter_btn:hover{
  background-color:#1aa0ef;
  color:#fff;
}
.banner_main_right .btns_sep{
  margin:10px 0;
  display:flex;
  align-items:center;
}
.banner_main_right .btns_sep .line{
  height:1px;
  border-bottom-width:1px;
  width:50%;
}
.banner_main_right .btns_sep .txt{
  padding:0 10px;
}
/*login Form*/
.banner_main_right #user_form_login{
  position:absolute;
  top:20px;
  left:0;
  right:0;
  margin:0;
  display:block;
  background:transparent !important;
  width:100%;
}
.banner_main_right #user_form_login > div > div > .form-elements{
  display:flex;
  flex-wrap:wrap;
  justify-content:center;
  align-items:center;
}
.banner_main_right #user_form_login div.form-wrapper{
  margin-right:10px;
}
.banner_main_right #user_form_login  div.form-label, 
.banner_main_right #user_form_login  #remember-wrapper, 
.banner_main_right #user_form_login  .user_showhidepassword{
  display:none;
}
.banner_main_right #user_form_login div.form-element{
  min-width:100%;
}
.banner_main_right #user_form_login  input[type=text], 
.banner_main_right #user_form_login  input[type=email], 
.banner_main_right #user_form_login input[type=password]{
  padding:12px 8px;
  width:160px !important;
}
.banner_main_right .global_form_box .form-wrapper+.form-wrapper{
  margin-top:0;
}
.banner_main_right #user_form_login #forgot-wrapper{
  position:absolute;
  left:51%;
  bottom:-30px;
  transform:translate(-45%, 0);
  margin:0;
}
.banner_main_right #user_form_login .form-element button{
  padding:12px 22px;
}
.banner_main_right #user_form_login #facebook-wrapper,
.banner_main_right #user_form_login #twitter-wrapper{
  width:100%;
  position:absolute;
  bottom:-90px;
  display:none;
}
.banner_main_right #user_form_login #facebook-wrapper{
  bottom:-155px !important;
}
.banner_main_right #user_form_login #twitter-element i,
.user_login_page .user_login_form #facebook-element i{
  width:40px;
  height:40px;
  border-radius:50px;
  line-height:40px;
  text-align:center;
}
/*Rensposvie**/
@media (max-width:1199px){
  .banner_main_right #user_form_login  input[type=text], 
  .banner_main_right #user_form_login  input[type=email], 
  .banner_main_right #user_form_login input[type=password]{
    padding:12px 8px;
    width:140px !important;
  }
}
@media (max-width:991px){
  .banner_landing_main_inner{
    height:100%;
  }
  .banner_main_left,
  .banner_main_right{
    width:100%;
    text-align:center;
  }
  .banner_main_right{
    padding:50px 0;
    height:100%;
    align-items:flex-start;
  }
  .banner_main_left{
    height:500px;
    padding:0;
  }
  .banner_main_left .layout_core_menu_logo img{
    margin:auto;
    display:block;
  }
  .banner_main_left_content{
    text-align:center !important
  }
  .banner_main_right .btn_group .btn{
    margin:auto;
  }
  .banner_main_right .landing-banner_right_inner{
    margin:0px auto;
    width:100%;
  }
  .banner_main_right #user_form_login{
    display:none;
  }
  
}
@media (max-width:767px){
  .banner_landing_main_inner{
    height:100vh;
  }
  .banner_main_left{
    display:none;
  }
  .banner_main_left .generic_layout_container.layout_core_menu_logo {
    margin:auto  !important;
    display:block !important;
    height:auto;
    padding:15px 0;
    text-align:center;
  }
  .banner_main_left .layout_core_menu_logo img{
    max-height:50px;
  }
  .banner_main_right{
    width:100%;
    height:auto;
    padding:20px;
    align-items:center;
    justify-content:center;
    display:flex;
    flex-direction:column;
  }
  .banner_main_right .landing-banner_right_inner{
    width:100%;
    margin:0px auto 0;
  }
  .banner_main_right h2{
    font-size:20px;
    margin-bottom:15px;
  }
  .banner_main_right p{
    font-size:16px;
    line-height:30px;
  }
  .banner_main_right .btn_group{
    width:100%;
    text-align:center;
  }
  .banner_main_right .layout_core_menu_logo{
    font-size:16px;
    height:auto;
    max-width:100%;
  }
  .banner_main_right .landing_subtitle{
    font-size:15px;
    margin:16px auto;
    margin-top:30px;
  }
  .banner_main_right #user_form_login{
    margin:0 5px;
  }
  .banner_main_right #user_form_login div.form-wrapper{
    margin-right:5px;
  }
  .banner_main_right #user_form_login .form-element button{
    padding:12px 14px;
  }
  .banner_main_right #user_form_login{
    display:none;
  }
}
@media (max-width:550px){
  .banner_main_right #user_form_login input[type=text], 
  .banner_main_right #user_form_login input[type=email], 
  .banner_main_right #user_form_login input[type=password]{
    width:100px !important;
  }
  .banner_main_right #user_form_login #forgot-wrapper{
    left:55%;
  }
}